@@ -27,7 +27,7 @@ func TestDynamoDBTemplate_MarshalBinary(t *testing.T) {
 			mockDependencies: func(ctrl *gomock.Controller, ddb *DynamoDBTemplate) {
 				m := mocks.NewMockParser(ctrl)
 				ddb.parser = m
-				m.EXPECT().Parse(dynamoDbTemplatePath, *ddb, gomock.Any()).Return(nil, errors.New("some error"))
+				m.EXPECT().Parse("mockPath", *ddb, gomock.Any()).Return(nil, errors.New("some error"))
 			},
 
 			wantedError: errors.New("some error"),
@@ -36,7 +36,7 @@ func TestDynamoDBTemplate_MarshalBinary(t *testing.T) {
 			mockDependencies: func(ctrl *gomock.Controller, ddb *DynamoDBTemplate) {
 				m := mocks.NewMockParser(ctrl)
 				ddb.parser = m
-				m.EXPECT().Parse(dynamoDbTemplatePath, *ddb, gomock.Any()).Return(&template.Content{Buffer: bytes.NewBufferString("hello")}, nil)
+				m.EXPECT().Parse("mockPath", *ddb, gomock.Any()).Return(&template.Content{Buffer: bytes.NewBufferString("hello")}, nil)
 
 			},
 
@@ -49,7 +49,9 @@ func TestDynamoDBTemplate_MarshalBinary(t *testing.T) {
 			// GIVEN
 			ctrl := gomock.NewController(t)
 			defer ctrl.Finish()
-			addon := &DynamoDBTemplate{}
+			addon := &DynamoDBTemplate{
+				tmplPath: "mockPath",
+			}
 			tc.mockDependencies(ctrl, addon)
 
 			// WHEN
@@ -73,7 +75,7 @@ func TestS3Template_MarshalBinary(t *testing.T) {
 			mockDependencies: func(ctrl *gomock.Controller, s3 *S3Template) {
 				m := mocks.NewMockParser(ctrl)
 				s3.parser = m
-				m.EXPECT().Parse(s3TemplatePath, *s3, gomock.Any()).Return(nil, errors.New("some error"))
+				m.EXPECT().Parse("mockPath", *s3, gomock.Any()).Return(nil, errors.New("some error"))
 			},
 
 			wantedError: errors.New("some error"),
@@ -82,7 +84,7 @@ func TestS3Template_MarshalBinary(t *testing.T) {
 			mockDependencies: func(ctrl *gomock.Controller, s3 *S3Template) {
 				m := mocks.NewMockParser(ctrl)
 				s3.parser = m
-				m.EXPECT().Parse(s3TemplatePath, *s3, gomock.Any()).Return(&template.Content{Buffer: bytes.NewBufferString("hello")}, nil)
+				m.EXPECT().Parse("mockPath", *s3, gomock.Any()).Return(&template.Content{Buffer: bytes.NewBufferString("hello")}, nil)
 
 			},
 
@@ -95,7 +97,9 @@ func TestS3Template_MarshalBinary(t *testing.T) {
 			// GIVEN
 			ctrl := gomock.NewController(t)
 			defer ctrl.Finish()
-			addon := &S3Template{}
+			addon := &S3Template{
+				tmplPath: "mockPath",
+			}
 			tc.mockDependencies(ctrl, addon)
 
 			// WHEN
@@ -110,9 +114,9 @@ func TestS3Template_MarshalBinary(t *testing.T) {
 
 func TestRDSTemplate_MarshalBinary(t *testing.T) {
 	testCases := map[string]struct {
-		workloadType     string
-		version          string
-		engine           string
+		version string
+		engine  string
+
 		mockDependencies func(ctrl *gomock.Controller, r *RDSTemplate)
 
 		wantedBinary []byte
@@ -134,7 +138,7 @@ func TestRDSTemplate_MarshalBinary(t *testing.T) {
 			mockDependencies: func(ctrl *gomock.Controller, r *RDSTemplate) {
 				m := mocks.NewMockParser(ctrl)
 				r.parser = m
-				m.EXPECT().Parse(gomock.Eq(rdsTemplatePath), *r, gomock.Any()).
+				m.EXPECT().Parse(gomock.Eq("mockPath"), *r, gomock.Any()).
 					Return(&template.Content{Buffer: bytes.NewBufferString("psql")}, nil)
 
 			},
@@ -146,31 +150,19 @@ func TestRDSTemplate_MarshalBinary(t *testing.T) {
 			mockDependencies: func(ctrl *gomock.Controller, r *RDSTemplate) {
 				m := mocks.NewMockParser(ctrl)
 				r.parser = m
-				m.EXPECT().Parse(gomock.Eq(rdsTemplatePath), *r, gomock.Any()).
+				m.EXPECT().Parse(gomock.Eq("mockPath"), *r, gomock.Any()).
 					Return(&template.Content{Buffer: bytes.NewBufferString("mysql")}, nil)
 
 			},
 			wantedBinary: []byte("mysql"),
 		},
-		"renders rdws rds v1 template": {
-			workloadType: "Request-Driven Web Service",
-			version:      auroraServerlessVersionV1,
-			engine:       RDSEngineTypeMySQL,
-			mockDependencies: func(ctrl *gomock.Controller, r *RDSTemplate) {
-				m := mocks.NewMockParser(ctrl)
-				r.parser = m
-				m.EXPECT().Parse(gomock.Eq(rdsRDWSTemplatePath), *r, gomock.Any()).
-					Return(&template.Content{Buffer: bytes.NewBufferString("mysql")}, nil)
-			},
-			wantedBinary: []byte("mysql"),
-		},
 		"renders postgresql v2 content": {
 			version: auroraServerlessVersionV2,
 			engine:  RDSEngineTypePostgreSQL,
 			mockDependencies: func(ctrl *gomock.Controller, r *RDSTemplate) {
 				m := mocks.NewMockParser(ctrl)
 				r.parser = m
-				m.EXPECT().Parse(gomock.Eq(rdsV2TemplatePath), *r, gomock.Any()).
+				m.EXPECT().Parse(gomock.Eq("mockPath"), *r, gomock.Any()).
 					Return(&template.Content{Buffer: bytes.NewBufferString("psql")}, nil)
 
 			},
@@ -182,24 +174,12 @@ func TestRDSTemplate_MarshalBinary(t *testing.T) {
 			mockDependencies: func(ctrl *gomock.Controller, r *RDSTemplate) {
 				m := mocks.NewMockParser(ctrl)
 				r.parser = m
-				m.EXPECT().Parse(gomock.Eq(rdsV2TemplatePath), *r, gomock.Any()).
+				m.EXPECT().Parse(gomock.Eq("mockPath"), *r, gomock.Any()).
 					Return(&template.Content{Buffer: bytes.NewBufferString("mysql")}, nil)
 
 			},
 			wantedBinary: []byte("mysql"),
 		},
-		"renders rdws rds v2 template": {
-			workloadType: "Request-Driven Web Service",
-			version:      auroraServerlessVersionV2,
-			engine:       RDSEngineTypeMySQL,
-			mockDependencies: func(ctrl *gomock.Controller, r *RDSTemplate) {
-				m := mocks.NewMockParser(ctrl)
-				r.parser = m
-				m.EXPECT().Parse(gomock.Eq(rdsRDWSV2TemplatePath), *r, gomock.Any()).
-					Return(&template.Content{Buffer: bytes.NewBufferString("mysql")}, nil)
-			},
-			wantedBinary: []byte("mysql"),
-		},
 	}
 
 	for name, tc := range testCases {
@@ -209,10 +189,9 @@ func TestRDSTemplate_MarshalBinary(t *testing.T) {
 			defer ctrl.Finish()
 			addon := &RDSTemplate{
 				RDSProps: RDSProps{
-					WorkloadType:            tc.workloadType,
-					auroraServerlessVersion: tc.version,
-					Engine:                  tc.engine,
+					Engine: tc.engine,
 				},
+				tmplPath: "mockPath",
 			}
 			tc.mockDependencies(ctrl, addon)
 
@@ -245,7 +224,8 @@ func TestRDSParams_MarshalBinary(t *testing.T) {
 			mockDependencies: func(ctrl *gomock.Controller, r *RDSParams) {
 				m := mocks.NewMockParser(ctrl)
 				r.parser = m
-				m.EXPECT().Parse(gomock.Eq(rdsRDWSParamsPath), *r, gomock.Any()).
+				r.tmplPath = "mockPath"
+				m.EXPECT().Parse(gomock.Eq("mockPath"), *r, gomock.Any()).
 					Return(&template.Content{Buffer: bytes.NewBufferString("bloop")}, nil)
 
 			},
@@ -536,3 +516,85 @@ func TestBuildLocalSecondaryIndex(t *testing.T) {
 		})
 	}
 }
+
+func TestConstructors(t *testing.T) {
+	t.Run("marshaler for workload-level S3", func(t *testing.T) {
+		out := WorkloadS3Template(&S3Props{})
+		require.Equal(t, s3TemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for env-level S3", func(t *testing.T) {
+		out := EnvS3Template(&S3Props{})
+		require.Equal(t, envS3TemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for the access policy of an env-level S3", func(t *testing.T) {
+		out := EnvS3AccessPolicyTemplate(&AccessPolicyProps{})
+		require.Equal(t, envS3AccessPolicyTemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for workload-level ddb", func(t *testing.T) {
+		out := WorkloadDDBTemplate(&DynamoDBProps{})
+		require.Equal(t, dynamoDbTemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for env-level ddb", func(t *testing.T) {
+		out := EnvDDBTemplate(&DynamoDBProps{})
+		require.Equal(t, envDynamoDBTemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for the access policy of an env-level ddb", func(t *testing.T) {
+		out := EnvDDBAccessPolicyTemplate(&AccessPolicyProps{})
+		require.Equal(t, envDynamoDBAccessPolicyTemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for non-RDWS workload-level aurora serverless v1", func(t *testing.T) {
+		out := WorkloadServerlessV1Template(RDSProps{})
+		require.Equal(t, rdsTemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for non-RDWS workload-level aurora serverless v2", func(t *testing.T) {
+		out := WorkloadServerlessV2Template(RDSProps{})
+		require.Equal(t, rdsV2TemplatePath, out.tmplPath)
+	})
+
+	t.Run("parameter marshaler for RDWS workload-level aurora serverless v1/v2", func(t *testing.T) {
+		out := RDWSParamsForRDS()
+		require.Equal(t, rdsRDWSParamsPath, out.tmplPath)
+	})
+
+	t.Run("marshaler for RDWS workload-level aurora serverless v1", func(t *testing.T) {
+		out := RDWSServerlessV1Template(RDSProps{})
+		require.Equal(t, rdsRDWSTemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for RDWS workload-level aurora serverless v2", func(t *testing.T) {
+		out := RDWSServerlessV2Template(RDSProps{})
+		require.Equal(t, rdsV2RDWSTemplatePath, out.tmplPath)
+	})
+
+	t.Run("parameter marshaler for env-level aurora accessible by a workload", func(t *testing.T) {
+		out := EnvParamsForRDS()
+		require.Equal(t, envRDSParamsPath, out.tmplPath)
+	})
+
+	t.Run("marshaler for env-level aurora accessible by a non-RDWS", func(t *testing.T) {
+		out := EnvServerlessTemplate(RDSProps{})
+		require.Equal(t, envRDSTemplatePath, out.tmplPath)
+	})
+
+	t.Run("marshaler for env-level aurora accessible by an RDWS", func(t *testing.T) {
+		out := EnvServerlessForRDWSTemplate(RDSProps{})
+		require.Equal(t, envRDSForRDWSTemplatePath, out.tmplPath)
+	})
+
+	t.Run("parameter marshaler for the ingress attached to an RDWS for an env-level aurora", func(t *testing.T) {
+		out := RDWSParamsForEnvRDS()
+		require.Equal(t, envRDSIngressForRDWSParamsPath, out.tmplPath)
+	})
+
+	t.Run("marshaler for the ingress attached to an RDWS for an env-level aurora", func(t *testing.T) {
+		out := EnvServerlessRDWSIngressTemplate(RDSIngressProps{})
+		require.Equal(t, envRDSIngressForRDWSTemplatePath, out.tmplPath)
+	})
+}
