@@ -31,6 +31,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/describe"
 	"github.com/aws/copilot-cli/internal/pkg/describe/stack"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
+	"github.com/aws/copilot-cli/internal/pkg/override"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/aws/copilot-cli/internal/pkg/template/artifactpath"
 	"github.com/aws/copilot-cli/internal/pkg/term/log"
@@ -94,7 +95,7 @@ type envDeployer struct {
 	appCFN                   appResourcesGetter
 	envDeployer              environmentDeployer
 	patcher                  patcher
-	newStackSerializer       func(input *cfnstack.EnvConfig, forceUpdateID string, prevParams []*awscfn.Parameter) stackSerializer
+	newStack                 func(input *cfnstack.EnvConfig, forceUpdateID string, prevParams []*awscfn.Parameter) (deploycfn.StackConfiguration, error)
 	envDescriber             envDescriber
 	lbDescriber              lbDescriber
 	newServiceStackDescriber func(string) stackDescriber
@@ -116,6 +117,7 @@ type NewEnvDeployerInput struct {
 	SessionProvider *sessions.Provider
 	ConfigStore     describe.ConfigStoreSvc
 	Workspace       WorkspaceAddonsReaderPathGetter
+	Overrider       Overrider
 }
 
 // NewEnvDeployer constructs an environment deployer.
@@ -140,6 +142,10 @@ func NewEnvDeployer(in *NewEnvDeployerInput) (*envDeployer, error) {
 	if err != nil {
 		return nil, fmt.Errorf("initialize env describer: %w", err)
 	}
+	overrider := in.Overrider
+	if overrider == nil {
+		overrider = new(override.Noop)
+	}
 	cfnClient := deploycfn.New(envManagerSession, deploycfn.WithProgressTracker(os.Stderr))
 	deployer := &envDeployer{
 		app: in.App,
@@ -156,8 +162,12 @@ func NewEnvDeployer(in *NewEnvDeployerInput) (*envDeployer, error) {
 			TemplatePatcher: cfnClient,
 			Env:             in.Env,
 		},
-		newStackSerializer: func(in *cfnstack.EnvConfig, lastForceUpdateID string, oldParams []*awscfn.Parameter) stackSerializer {
-			return cfnstack.NewEnvConfigFromExistingStack(in, lastForceUpdateID, oldParams)
+		newStack: func(in *cfnstack.EnvConfig, lastForceUpdateID string, oldParams []*awscfn.Parameter) (deploycfn.StackConfiguration, error) {
+			stack, err := cfnstack.NewEnvConfigFromExistingStack(in, lastForceUpdateID, oldParams)
+			if err != nil {
+				return nil, err
+			}
+			return deploycfn.WrapWithTemplateOverrider(stack, overrider), nil
 		},
 		envDescriber: envDescriber,
 		lbDescriber:  elbv2.New(envManagerSession),
@@ -253,7 +263,10 @@ func (d *envDeployer) GenerateCloudFormationTemplate(in *DeployEnvironmentInput)
 	if err != nil {
 		return nil, fmt.Errorf("retrieve environment stack force update ID: %w", err)
 	}
-	stack := d.newStackSerializer(stackInput, lastForceUpdateID, oldParams)
+	stack, err := d.newStack(stackInput, lastForceUpdateID, oldParams)
+	if err != nil {
+		return nil, err
+	}
 	tpl, err := stack.Template()
 	if err != nil {
 		return nil, fmt.Errorf("generate stack template: %w", err)
@@ -288,8 +301,11 @@ func (d *envDeployer) DeployEnvironment(in *DeployEnvironmentInput) error {
 	if in.DisableRollback {
 		opts = append(opts, awscloudformation.WithDisableRollback())
 	}
-	conf := cfnstack.NewEnvConfigFromExistingStack(stackInput, lastForceUpdateID, oldParams)
-	return d.envDeployer.UpdateAndRenderEnvironment(conf, stackInput.ArtifactBucketARN, opts...)
+	stack, err := d.newStack(stackInput, lastForceUpdateID, oldParams)
+	if err != nil {
+		return err
+	}
+	return d.envDeployer.UpdateAndRenderEnvironment(stack, stackInput.ArtifactBucketARN, opts...)
 }
 
 func (d *envDeployer) getAppRegionalResources() (*cfnstack.AppRegionalResources, error) {
