@@ -143,6 +143,8 @@ type workloadDeployer struct {
 	spinner            spinner
 	templateFS         template.Reader
 	envVersionGetter   versionGetter
+	overrider          Overrider
+	customResources    customResourcesFunc
 
 	// Cached variables.
 	defaultSess              *session.Session
@@ -162,6 +164,10 @@ type WorkloadDeployerInput struct {
 	Mft              interface{} // Interpolated, applied, and unmarshaled manifest.
 	RawMft           []byte      // Content of the manifest file without any transformations.
 	EnvVersionGetter versionGetter
+	Overrider        Overrider
+
+	// Workload specific configuration.
+	customResources customResourcesFunc
 }
 
 // newWorkloadDeployer is the constructor for workloadDeployer.
@@ -235,6 +241,8 @@ func newWorkloadDeployer(in *WorkloadDeployerInput) (*workloadDeployer, error) {
 		spinner:            termprogress.NewSpinner(log.DiagnosticWriter),
 		templateFS:         template.New(),
 		envVersionGetter:   in.EnvVersionGetter,
+		overrider:          in.Overrider,
+		customResources:    in.customResources,
 
 		defaultSess:              defaultSession,
 		defaultSessWithEnvRegion: defaultSessEnvRegion,
@@ -260,7 +268,7 @@ func (d *workloadDeployer) generateCloudFormationTemplate(conf stackSerializer)
 	*GenerateCloudFormationTemplateOutput, error) {
 	tpl, err := conf.Template()
 	if err != nil {
-		return nil, fmt.Errorf("generate stack template: %w", err)
+		return nil, err
 	}
 	params, err := conf.SerializedParameters()
 	if err != nil {
@@ -377,7 +385,7 @@ type UploadArtifactsOutput struct {
 	CustomResourceURLs map[string]string
 }
 
-func (d *workloadDeployer) uploadArtifacts(customResources customResourcesFunc) (*UploadArtifactsOutput, error) {
+func (d *workloadDeployer) uploadArtifacts() (*UploadArtifactsOutput, error) {
 	imageDigest, err := d.uploadContainerImage(d.imageBuilderPusher)
 	if err != nil {
 		return nil, err
@@ -395,7 +403,7 @@ func (d *workloadDeployer) uploadArtifacts(customResources customResourcesFunc)
 		EnvFileARN:  s3Artifacts.envFileARN,
 		AddonsURL:   s3Artifacts.addonsURL,
 	}
-	crs, err := customResources(d.templateFS)
+	crs, err := d.customResources(d.templateFS)
 	if err != nil {
 		return nil, err
 	}
