@@ -13,8 +13,11 @@ import (
 	"testing"
 	"time"
 
+	cloudformation0 "github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation"
+
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
+	sdkcfn "github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/aws/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/cli/deploy/mocks"
@@ -24,6 +27,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/deploy/upload/customresource"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
+	"github.com/aws/copilot-cli/internal/pkg/override"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/aws/copilot-cli/internal/pkg/term/color"
 	"github.com/aws/copilot-cli/internal/pkg/term/log"
@@ -66,6 +70,36 @@ func fakeTemplateFS() *mockTemplateFS {
 	}
 }
 
+type mockEndpointGetter struct {
+	endpoint string
+	err      error
+}
+
+// ServiceDiscoveryEndpoint implements the endpointGetter interface.
+func (m *mockEndpointGetter) ServiceDiscoveryEndpoint() (string, error) {
+	return m.endpoint, m.err
+}
+
+type mockEnvVersionGetter struct {
+	version string
+	err     error
+}
+
+// Version implements the envVersionGetter interface.
+func (m *mockEnvVersionGetter) Version() (string, error) {
+	return m.version, m.err
+}
+
+type mockTopicLister struct {
+	topics []deploy.Topic
+	err    error
+}
+
+// ListSNSTopics implements the snsTopicsLister interface.
+func (m *mockTopicLister) ListSNSTopics(_, _ string) ([]deploy.Topic, error) {
+	return m.topics, m.err
+}
+
 type mockWorkloadMft struct {
 	fileName      string
 	buildRequired bool
@@ -90,6 +124,28 @@ func (m *mockWorkloadMft) ContainerPlatform() string {
 	return "mockContainerPlatform"
 }
 
+// stubCloudFormationStack implements the cloudformation.StackConfiguration interface.
+type stubCloudFormationStack struct{}
+
+func (s *stubCloudFormationStack) StackName() string {
+	return "demo"
+}
+func (s *stubCloudFormationStack) Template() (string, error) {
+	return `
+Resources:
+  Queue:
+    Type: AWS::SQS::Queue`, nil
+}
+func (s *stubCloudFormationStack) Parameters() ([]*sdkcfn.Parameter, error) {
+	return []*sdkcfn.Parameter{}, nil
+}
+func (s *stubCloudFormationStack) Tags() []*sdkcfn.Tag {
+	return []*sdkcfn.Tag{}
+}
+func (s *stubCloudFormationStack) SerializedParameters() (string, error) {
+	return "", nil
+}
+
 func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 	const (
 		mockName            = "mockWkld"
@@ -121,6 +177,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 
 		mock                func(t *testing.T, m *deployMocks)
 		mockServiceDeployer func(deployer *workloadDeployer) artifactsUploader
+		customResourcesFunc customResourcesFunc
 
 		wantAddonsURL     string
 		wantEnvFileARN    string
@@ -170,14 +227,14 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					return "", errors.New("did not match any custom resource")
 				}).Times(len(crs))
 			},
+			customResourcesFunc: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+				return customresource.LBWS(fs)
+			},
 			mockServiceDeployer: func(deployer *workloadDeployer) artifactsUploader {
 				return &lbWebSvcDeployer{
 					svcDeployer: &svcDeployer{
 						workloadDeployer: deployer,
 					},
-					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
-						return customresource.LBWS(fs)
-					},
 				}
 			},
 		},
@@ -198,14 +255,14 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					return "", errors.New("did not match any custom resource")
 				}).Times(len(crs))
 			},
+			customResourcesFunc: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+				return customresource.Backend(fs)
+			},
 			mockServiceDeployer: func(deployer *workloadDeployer) artifactsUploader {
 				return &backendSvcDeployer{
 					svcDeployer: &svcDeployer{
 						workloadDeployer: deployer,
 					},
-					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
-						return customresource.Backend(fs)
-					},
 				}
 			},
 		},
@@ -226,14 +283,14 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					return "", errors.New("did not match any custom resource")
 				}).Times(len(crs))
 			},
+			customResourcesFunc: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+				return customresource.Worker(fs)
+			},
 			mockServiceDeployer: func(deployer *workloadDeployer) artifactsUploader {
 				return &workerSvcDeployer{
 					svcDeployer: &svcDeployer{
 						workloadDeployer: deployer,
 					},
-					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
-						return customresource.Worker(fs)
-					},
 				}
 			},
 		},
@@ -254,14 +311,14 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					return "", errors.New("did not match any custom resource")
 				}).Times(len(crs))
 			},
+			customResourcesFunc: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+				return customresource.RDWS(fs)
+			},
 			mockServiceDeployer: func(deployer *workloadDeployer) artifactsUploader {
 				return &rdwsDeployer{
 					svcDeployer: &svcDeployer{
 						workloadDeployer: deployer,
 					},
-					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
-						return customresource.RDWS(fs)
-					},
 				}
 			},
 		},
@@ -282,12 +339,12 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					return "", errors.New("did not match any custom resource")
 				}).Times(len(crs))
 			},
+			customResourcesFunc: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+				return customresource.ScheduledJob(fs)
+			},
 			mockServiceDeployer: func(deployer *workloadDeployer) artifactsUploader {
 				return &jobDeployer{
 					workloadDeployer: deployer,
-					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
-						return customresource.ScheduledJob(fs)
-					},
 				}
 			},
 		},
@@ -388,6 +445,13 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 			}
 			tc.mock(t, m)
 
+			crFn := tc.customResourcesFunc
+			if crFn == nil {
+				crFn = func(fs template.Reader) ([]*customresource.CustomResource, error) {
+					return nil, nil
+				}
+			}
+
 			wkldDeployer := &workloadDeployer{
 				name: mockName,
 				env: &config.Environment{
@@ -408,6 +472,8 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 				s3Client:           m.mockUploader,
 				imageBuilderPusher: m.mockImageBuilderPusher,
 				templateFS:         fakeTemplateFS(),
+				overrider:          new(override.Noop),
+				customResources:    crFn,
 			}
 			if m.mockAddons != nil {
 				wkldDeployer.addons = m.mockAddons
@@ -417,9 +483,6 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 				svcDeployer: &svcDeployer{
 					workloadDeployer: wkldDeployer,
 				},
-				customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
-					return nil, nil
-				},
 			}
 			if tc.mockServiceDeployer != nil {
 				deployer = tc.mockServiceDeployer(wkldDeployer)
@@ -1121,6 +1184,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 						endpointGetter:   m.mockEndpointGetter,
 						spinner:          m.mockSpinner,
 						envVersionGetter: m.mockEnvVersionGetter,
+						overrider:        new(override.Noop),
 					},
 					newSvcUpdater: func(f func(*session.Session) serviceForceUpdater) serviceForceUpdater {
 						return m.mockServiceForceUpdater
@@ -1142,7 +1206,9 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 						ImageConfig: manifest.ImageWithPortAndHealthcheck{
 							ImageWithPort: manifest.ImageWithPort{
 								Image: manifest.Image{
-									Build: manifest.BuildArgsOrString{BuildString: aws.String("/Dockerfile")},
+									ImageLocationOrBuild: manifest.ImageLocationOrBuild{
+										Build: manifest.BuildArgsOrString{BuildString: aws.String("/Dockerfile")},
+									},
 								},
 								Port: aws.Uint16(80),
 							},
@@ -1157,6 +1223,9 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 						NLBConfig: tc.inNLB,
 					},
 				},
+				newStack: func() cloudformation0.StackConfiguration {
+					return new(stubCloudFormationStack)
+				},
 			}
 
 			_, gotErr := deployer.DeployWorkload(&DeployWorkloadInput{
