@@ -284,6 +284,24 @@ type wlLister interface {
 	ListWorkloads() ([]string, error)
 }
 
+type wsWorkloadReader interface {
+	manifestReader
+	ReadFile(path string) ([]byte, error)
+	WorkloadExists(name string) (bool, error)
+	WorkloadAddonFilePath(wkldName, fName string) string
+	WorkloadAddonFileAbsPath(wkldName, fName string) string
+}
+
+type wsWorkloadReadWriter interface {
+	wsWorkloadReader
+	wsWriter
+}
+
+type wsReadWriter interface {
+	wsWorkloadReadWriter
+	wsEnvironmentReader
+}
+
 type wsJobDirReader interface {
 	wsJobReader
 	workspacePathGetter
@@ -295,12 +313,17 @@ type wsWlDirReader interface {
 	workspacePathGetter
 	wlLister
 	wsEnvironmentsLister
+	WorkloadOverridesPath(string) string
 	Summary() (*workspace.Summary, error)
 }
 
 type wsEnvironmentReader interface {
 	wsEnvironmentsLister
+	HasEnvironments() (bool, error)
+	EnvOverridesPath() string
 	ReadEnvironmentManifest(mftDirName string) (workspace.EnvironmentManifest, error)
+	EnvAddonFilePath(fName string) string
+	EnvAddonFileAbsPath(fName string) string
 }
 
 type wsPipelineReader interface {
@@ -318,10 +341,8 @@ type wsAppManager interface {
 	Summary() (*workspace.Summary, error)
 }
 
-type wsAddonManager interface {
-	WriteAddon(f encoding.BinaryMarshaler, svc, name string) (string, error)
-	manifestReader
-	wlLister
+type wsWriter interface {
+	Write(content encoding.BinaryMarshaler, path string) (string, error)
 }
 
 type uploader interface {
@@ -471,6 +492,7 @@ type configSelector interface {
 	appEnvSelector
 	Service(prompt, help, app string) (string, error)
 	Job(prompt, help, app string) (string, error)
+	Workload(prompt, help, app string) (string, error)
 }
 
 type deploySelector interface {
