@@ -8,8 +8,6 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
-
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	awsecs "github.com/aws/copilot-cli/internal/pkg/aws/ecs"
@@ -24,6 +22,7 @@ import (
 
 type execSvcMocks struct {
 	storeSvc           *mocks.Mockstore
+	sessProvider       *mocks.MocksessionProvider
 	sel                *mocks.MockdeploySelector
 	ecsSvcDescriber    *mocks.MockserviceDescriber
 	ecsCommandExecutor *mocks.MockecsCommandExecutor
@@ -279,8 +278,8 @@ func TestSvcExec_Ask(t *testing.T) {
 				m.storeSvc.EXPECT().GetService("my-app", "my-svc").Return(&config.Workload{}, nil)
 				m.sel.EXPECT().DeployedService(svcExecNamePrompt, svcExecNameHelpPrompt, "my-app", gomock.Any(), gomock.Any()).
 					Return(&selector.DeployedService{
-						Env: "my-env",
-						Svc: "my-svc",
+						Env:  "my-env",
+						Name: "my-svc",
 					}, nil) // Let prompter handles the case when svc(env) is definite.
 			},
 			wantedApp: inputApp,
@@ -291,14 +290,14 @@ func TestSvcExec_Ask(t *testing.T) {
 			inputEnv: inputEnv,
 			inputSvc: inputSvc,
 			setupMocks: func(m execSvcMocks) {
-				m.sel.EXPECT().Application(svcAppNamePrompt, svcAppNameHelpPrompt).Return("my-app", nil)
+				m.sel.EXPECT().Application(svcAppNamePrompt, wkldAppNameHelpPrompt).Return("my-app", nil)
 				m.storeSvc.EXPECT().GetApplication(gomock.Any()).Times(0)
 				// Don't care about the other calls.
 				m.storeSvc.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).AnyTimes()
 				m.storeSvc.EXPECT().GetService(gomock.Any(), gomock.Any()).AnyTimes()
 				m.sel.EXPECT().DeployedService(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).Return(&selector.DeployedService{
-					Env: "my-env",
-					Svc: "my-svc",
+					Env:  "my-env",
+					Name: "my-svc",
 				}, nil).AnyTimes()
 			},
 			wantedApp: inputApp,
@@ -307,7 +306,7 @@ func TestSvcExec_Ask(t *testing.T) {
 		},
 		"returns error when fail to select apps": {
 			setupMocks: func(m execSvcMocks) {
-				m.sel.EXPECT().Application(svcAppNamePrompt, svcAppNameHelpPrompt).Return("", errors.New("some error"))
+				m.sel.EXPECT().Application(svcAppNamePrompt, wkldAppNameHelpPrompt).Return("", errors.New("some error"))
 			},
 			wantedError: fmt.Errorf("select application: some error"),
 		},
@@ -318,8 +317,8 @@ func TestSvcExec_Ask(t *testing.T) {
 				m.storeSvc.EXPECT().GetService(gomock.Any(), gomock.Any()).Times(0)
 				m.sel.EXPECT().DeployedService(svcExecNamePrompt, svcExecNameHelpPrompt, "my-app", gomock.Any(), gomock.Any()).
 					Return(&selector.DeployedService{
-						Env: "my-env",
-						Svc: "my-svc",
+						Env:  "my-env",
+						Name: "my-svc",
 					}, nil)
 				// Don't care about the other calls.
 				m.storeSvc.EXPECT().GetApplication(gomock.Any()).AnyTimes()
@@ -342,11 +341,11 @@ func TestSvcExec_Ask(t *testing.T) {
 		"success": {
 			setupMocks: func(m execSvcMocks) {
 				gomock.InOrder(
-					m.sel.EXPECT().Application(svcAppNamePrompt, svcAppNameHelpPrompt).Return("my-app", nil),
+					m.sel.EXPECT().Application(svcAppNamePrompt, wkldAppNameHelpPrompt).Return("my-app", nil),
 					m.sel.EXPECT().DeployedService(svcExecNamePrompt, svcExecNameHelpPrompt, "my-app", gomock.Any(), gomock.Any()).
 						Return(&selector.DeployedService{
-							Env: "my-env",
-							Svc: "my-svc",
+							Env:  "my-env",
+							Name: "my-svc",
 						}, nil),
 				)
 			},
@@ -452,6 +451,11 @@ func TestSvcExec_Execute(t *testing.T) {
 					m.storeSvc.EXPECT().GetEnvironment("mockApp", "mockEnv").Return(&config.Environment{
 						Name: "my-env",
 					}, nil),
+					m.sessProvider.EXPECT().FromRole(gomock.Any(), gomock.Any()).Return(&session.Session{
+						Config: &aws.Config{
+							Region: aws.String("mockRegion"),
+						},
+					}, nil),
 					m.ecsSvcDescriber.EXPECT().DescribeService("mockApp", "mockEnv", "mockSvc").Return(nil, mockError),
 				)
 			},
@@ -464,6 +468,11 @@ func TestSvcExec_Execute(t *testing.T) {
 					m.storeSvc.EXPECT().GetEnvironment("mockApp", "mockEnv").Return(&config.Environment{
 						Name: "my-env",
 					}, nil),
+					m.sessProvider.EXPECT().FromRole(gomock.Any(), gomock.Any()).Return(&session.Session{
+						Config: &aws.Config{
+							Region: aws.String("mockRegion"),
+						},
+					}, nil),
 					m.ecsSvcDescriber.EXPECT().DescribeService("mockApp", "mockEnv", "mockSvc").Return(&ecs.ServiceDesc{
 						Tasks: []*awsecs.Task{},
 					}, nil),
@@ -479,6 +488,11 @@ func TestSvcExec_Execute(t *testing.T) {
 					m.storeSvc.EXPECT().GetEnvironment("mockApp", "mockEnv").Return(&config.Environment{
 						Name: "my-env",
 					}, nil),
+					m.sessProvider.EXPECT().FromRole(gomock.Any(), gomock.Any()).Return(&session.Session{
+						Config: &aws.Config{
+							Region: aws.String("mockRegion"),
+						},
+					}, nil),
 					m.ecsSvcDescriber.EXPECT().DescribeService("mockApp", "mockEnv", "mockSvc").Return(&ecs.ServiceDesc{
 						Tasks: []*awsecs.Task{
 							{
@@ -499,6 +513,11 @@ func TestSvcExec_Execute(t *testing.T) {
 					m.storeSvc.EXPECT().GetEnvironment("mockApp", "mockEnv").Return(&config.Environment{
 						Name: "my-env",
 					}, nil),
+					m.sessProvider.EXPECT().FromRole(gomock.Any(), gomock.Any()).Return(&session.Session{
+						Config: &aws.Config{
+							Region: aws.String("mockRegion"),
+						},
+					}, nil),
 					m.ecsSvcDescriber.EXPECT().DescribeService("mockApp", "mockEnv", "mockSvc").Return(&ecs.ServiceDesc{
 						ClusterName: "mockCluster",
 						Tasks: []*awsecs.Task{
@@ -525,6 +544,11 @@ func TestSvcExec_Execute(t *testing.T) {
 					m.storeSvc.EXPECT().GetEnvironment("mockApp", "mockEnv").Return(&config.Environment{
 						Name: "my-env",
 					}, nil),
+					m.sessProvider.EXPECT().FromRole(gomock.Any(), gomock.Any()).Return(&session.Session{
+						Config: &aws.Config{
+							Region: aws.String("mockRegion"),
+						},
+					}, nil),
 					m.ecsSvcDescriber.EXPECT().DescribeService("mockApp", "mockEnv", "mockSvc").Return(&ecs.ServiceDesc{
 						ClusterName: "mockCluster",
 						Tasks: []*awsecs.Task{
@@ -557,6 +581,7 @@ func TestSvcExec_Execute(t *testing.T) {
 			mockStoreReader := mocks.NewMockstore(ctrl)
 			mockSvcDescriber := mocks.NewMockserviceDescriber(ctrl)
 			mockCommandExecutor := mocks.NewMockecsCommandExecutor(ctrl)
+			mockSessionProvider := mocks.NewMocksessionProvider(ctrl)
 			mockNewSvcDescriber := func(_ *session.Session) serviceDescriber {
 				return mockSvcDescriber
 			}
@@ -568,6 +593,7 @@ func TestSvcExec_Execute(t *testing.T) {
 				storeSvc:           mockStoreReader,
 				ecsCommandExecutor: mockCommandExecutor,
 				ecsSvcDescriber:    mockSvcDescriber,
+				sessProvider:       mockSessionProvider,
 			}
 
 			tc.setupMocks(mocks)
@@ -585,7 +611,7 @@ func TestSvcExec_Execute(t *testing.T) {
 				newSvcDescriber:    mockNewSvcDescriber,
 				newCommandExecutor: mockNewCommandExecutor,
 				randInt:            func(i int) int { return 0 },
-				sessProvider:       sessions.ImmutableProvider(),
+				sessProvider:       mockSessionProvider,
 			}
 
 			// WHEN
