@@ -323,6 +323,7 @@ type deleteTaskMocks struct {
 	store   *mocks.Mockstore
 	sess    *mocks.MocksessionProvider
 	ecr     *mocks.MockimageRemover
+	s3      *mocks.MockbucketEmptier
 	ecs     *mocks.MocktaskStopper
 	cfn     *mocks.MocktaskStackManager
 	spinner *mocks.Mockprogress
@@ -347,9 +348,14 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 		Env:     mockEnvName,
 		RoleARN: mockManagerARN,
 
-		StackName: mockTaskStackName,
+		StackName:  mockTaskStackName,
+		BucketName: "arn:aws:s3:::bucket",
 	}
 	mockDefaultTask := deploy.TaskStackInfo{
+		StackName:  mockTaskStackName,
+		BucketName: "arn:aws:s3:::bucket",
+	}
+	mockDefaultTaskNoBucket := deploy.TaskStackInfo{
 		StackName: mockTaskStackName,
 	}
 	mockError := errors.New("some error")
@@ -386,6 +392,9 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 					m.spinner.EXPECT().Stop(gomock.Any()),
 					m.cfn.EXPECT().GetTaskStack(mockTaskName).Return(mockAppEnvTask, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
+					m.s3.EXPECT().EmptyBucket(gomock.Any()).Return(nil),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+					m.spinner.EXPECT().Start(gomock.Any()),
 					m.cfn.EXPECT().DeleteTask(*mockAppEnvTask).Return(nil),
 					m.spinner.EXPECT().Stop(gomock.Any()),
 				)
@@ -406,11 +415,34 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 					m.spinner.EXPECT().Stop(gomock.Any()),
 					m.cfn.EXPECT().GetTaskStack(mockTaskName).Return(&mockDefaultTask, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
+					m.s3.EXPECT().EmptyBucket(gomock.Any()).Return(nil),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+					m.spinner.EXPECT().Start(gomock.Any()),
 					m.cfn.EXPECT().DeleteTask(mockDefaultTask).Return(nil),
 					m.spinner.EXPECT().Stop(gomock.Any()),
 				)
 			},
 		},
+		"success with default cluster and no S3 bucket": {
+			inDefault: true,
+			inName:    mockTaskName,
+
+			setupMocks: func(m deleteTaskMocks) {
+				gomock.InOrder(
+					m.sess.EXPECT().Default().Return(&session.Session{}, nil),
+					m.spinner.EXPECT().Start(gomock.Any()),
+					m.ecs.EXPECT().StopDefaultClusterTasks(mockTaskName).Return(nil),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+					m.spinner.EXPECT().Start(gomock.Any()),
+					m.ecr.EXPECT().ClearRepository(mockTaskRepoName).Return(nil),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+					m.cfn.EXPECT().GetTaskStack(mockTaskName).Return(&mockDefaultTaskNoBucket, nil),
+					m.spinner.EXPECT().Start(gomock.Any()),
+					m.cfn.EXPECT().DeleteTask(mockDefaultTaskNoBucket).Return(nil),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+				)
+			},
+		},
 		"error when getting environment": {
 			inApp:  mockApp,
 			inEnv:  mockEnvName,
@@ -448,6 +480,9 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 					m.spinner.EXPECT().Stop(gomock.Any()),
 					m.cfn.EXPECT().GetTaskStack(mockTaskName).Return(mockAppEnvTask, nil),
 					m.spinner.EXPECT().Start(gomock.Any()),
+					m.s3.EXPECT().EmptyBucket(gomock.Any()).Return(nil),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+					m.spinner.EXPECT().Start(gomock.Any()),
 					m.cfn.EXPECT().DeleteTask(*mockAppEnvTask).Return(mockError),
 					m.spinner.EXPECT().Stop(gomock.Any()),
 				)
@@ -483,7 +518,7 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			inEnv:  mockEnvName,
 			inName: mockTaskName,
 
-			wantedErr: errors.New("clear ECR repository for task hide-snacks: some error"),
+			wantedErr: errors.New("empty ECR repository for task hide-snacks: some error"),
 
 			setupMocks: func(m deleteTaskMocks) {
 				m.sess.EXPECT().FromRole(mockEnv.ManagerRoleARN, mockEnv.Region).Return(&session.Session{
@@ -503,6 +538,35 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 				)
 			},
 		},
+		"error clearing s3 bucket": {
+			inApp:  mockApp,
+			inEnv:  mockEnvName,
+			inName: mockTaskName,
+
+			wantedErr: errors.New("empty S3 bucket for task hide-snacks: some error"),
+
+			setupMocks: func(m deleteTaskMocks) {
+				m.sess.EXPECT().FromRole(mockEnv.ManagerRoleARN, mockEnv.Region).Return(&session.Session{
+					Config: &aws.Config{
+						Region: aws.String("mockRegion"),
+					},
+				}, nil)
+				m.sess.EXPECT().DefaultWithRegion("mockRegion").Return(&session.Session{}, nil)
+				gomock.InOrder(
+					m.store.EXPECT().GetEnvironment(mockApp, mockEnvName).Return(mockEnv, nil),
+					m.spinner.EXPECT().Start(gomock.Any()),
+					m.ecs.EXPECT().StopOneOffTasks(mockApp, mockEnvName, mockTaskName).Return(nil),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+					m.spinner.EXPECT().Start(gomock.Any()),
+					m.ecr.EXPECT().ClearRepository(mockTaskRepoName).Return(nil),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+					m.cfn.EXPECT().GetTaskStack(mockTaskName).Return(mockAppEnvTask, nil),
+					m.spinner.EXPECT().Start(gomock.Any()),
+					m.s3.EXPECT().EmptyBucket(gomock.Any()).Return(mockError),
+					m.spinner.EXPECT().Stop(gomock.Any()),
+				)
+			},
+		},
 		"error stopping app/env tasks": {
 			inApp:  mockApp,
 			inEnv:  mockEnvName,
@@ -575,6 +639,7 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			// GIVEN
 			mockstore := mocks.NewMockstore(ctrl)
 			mockECR := mocks.NewMockimageRemover(ctrl)
+			mockS3 := mocks.NewMockbucketEmptier(ctrl)
 			mockCFN := mocks.NewMocktaskStackManager(ctrl)
 			mockECS := mocks.NewMocktaskStopper(ctrl)
 			//mockSession := sessions.NewProvider()
@@ -584,6 +649,9 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 			mockGetECR := func(_ *session.Session) imageRemover {
 				return mockECR
 			}
+			mockGetS3 := func(_ *session.Session) bucketEmptier {
+				return mockS3
+			}
 			mockGetECS := func(_ *session.Session) taskStopper {
 				return mockECS
 			}
@@ -595,6 +663,7 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 				store:   mockstore,
 				sess:    mockSession,
 				ecr:     mockECR,
+				s3:      mockS3,
 				ecs:     mockECS,
 				cfn:     mockCFN,
 				spinner: mockSpinner,
@@ -613,9 +682,10 @@ func TestDeleteTaskOpts_Execute(t *testing.T) {
 				provider: mockSession,
 				spinner:  mockSpinner,
 
-				newImageRemover: mockGetECR,
-				newStackManager: mockGetCFN,
-				newTaskStopper:  mockGetECS,
+				newImageRemover:  mockGetECR,
+				newBucketEmptier: mockGetS3,
+				newStackManager:  mockGetCFN,
+				newTaskStopper:   mockGetECS,
 			}
 
 			// WHEN
