@@ -9,10 +9,9 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/aws/copilot-cli/internal/pkg/workspace"
 
-	"github.com/aws/copilot-cli/internal/pkg/manifest"
-
 	"github.com/spf13/afero"
 
 	"github.com/stretchr/testify/require"
@@ -93,7 +92,7 @@ func TestValidateSvcName(t *testing.T) {
 	}{
 		"string as input": {
 			val:     "hello",
-			svcType: manifest.LoadBalancedWebServiceType,
+			svcType: manifestinfo.LoadBalancedWebServiceType,
 			wanted:  nil,
 		},
 		"number as input": {
@@ -106,27 +105,27 @@ func TestValidateSvcName(t *testing.T) {
 		},
 		"longer than 40 characters for app runner services": {
 			val:     strings.Repeat("x", 41),
-			svcType: manifest.RequestDrivenWebServiceType,
+			svcType: manifestinfo.RequestDrivenWebServiceType,
 			wanted:  errAppRunnerSvcNameTooLong,
 		},
 		"invalid length string": {
 			val:     strings.Repeat("s", 256),
-			svcType: manifest.LoadBalancedWebServiceType,
+			svcType: manifestinfo.LoadBalancedWebServiceType,
 			wanted:  errValueTooLong,
 		},
 		"does not start with letter": {
 			val:     "123chicken",
-			svcType: manifest.BackendServiceType,
+			svcType: manifestinfo.BackendServiceType,
 			wanted:  errValueBadFormat,
 		},
 		"contains upper-case letters": {
 			val:     "badGoose",
-			svcType: manifest.LoadBalancedWebServiceType,
+			svcType: manifestinfo.LoadBalancedWebServiceType,
 			wanted:  errValueBadFormat,
 		},
 		"is not a reserved name": {
 			val:     "pipelines",
-			svcType: manifest.LoadBalancedWebServiceType,
+			svcType: manifestinfo.LoadBalancedWebServiceType,
 			wanted:  errValueReserved,
 		},
 	}
