@@ -11,16 +11,13 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/config"
+	"github.com/aws/copilot-cli/internal/pkg/deploy/upload/customresource"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/aws/copilot-cli/internal/pkg/template/override"
 )
 
-type backendSvcReadParser interface {
-	template.ReadParser
-	ParseBackendService(template.WorkloadOpts) (*template.Content, error)
-}
-
 // BackendService represents the configuration needed to create a CloudFormation stack from a backend service manifest.
 type BackendService struct {
 	*ecsWkld
@@ -28,42 +25,50 @@ type BackendService struct {
 	httpsEnabled bool
 	albEnabled   bool
 
-	parser backendSvcReadParser
+	parser   backendSvcReadParser
+	localCRs []uploadable // Custom resources that have not been uploaded yet.
 }
 
 // BackendServiceConfig contains data required to initialize a backend service stack.
 type BackendServiceConfig struct {
-	App           *config.Application
-	EnvManifest   *manifest.Environment
-	Manifest      *manifest.BackendService
-	RawManifest   []byte // Content of the manifest file without any transformations.
-	RuntimeConfig RuntimeConfig
-	Addons        NestedStackConfigurer
+	App                *config.Application
+	EnvManifest        *manifest.Environment
+	Manifest           *manifest.BackendService
+	ArtifactBucketName string
+	RawManifest        []byte // Content of the manifest file without any transformations.
+	RuntimeConfig      RuntimeConfig
+	Addons             NestedStackConfigurer
 }
 
 // NewBackendService creates a new BackendService stack from a manifest file.
 func NewBackendService(conf BackendServiceConfig) (*BackendService, error) {
-	parser := template.New()
+	crs, err := customresource.Backend(fs)
+	if err != nil {
+		return nil, fmt.Errorf("backend service custom resources: %w", err)
+	}
+
 	b := &BackendService{
 		ecsWkld: &ecsWkld{
 			wkld: &wkld{
-				name:        aws.StringValue(conf.Manifest.Name),
-				env:         aws.StringValue(conf.EnvManifest.Name),
-				app:         conf.App.Name,
-				permBound:   conf.App.PermissionsBoundary,
-				rc:          conf.RuntimeConfig,
-				image:       conf.Manifest.ImageConfig.Image,
-				rawManifest: conf.RawManifest,
-				parser:      parser,
-				addons:      conf.Addons,
+				name:               aws.StringValue(conf.Manifest.Name),
+				env:                aws.StringValue(conf.EnvManifest.Name),
+				app:                conf.App.Name,
+				permBound:          conf.App.PermissionsBoundary,
+				artifactBucketName: conf.ArtifactBucketName,
+				rc:                 conf.RuntimeConfig,
+				image:              conf.Manifest.ImageConfig.Image,
+				rawManifest:        conf.RawManifest,
+				parser:             fs,
+				addons:             conf.Addons,
 			},
 			logRetention:        conf.Manifest.Logging.Retention,
 			tc:                  conf.Manifest.TaskConfig,
 			taskDefOverrideFunc: override.CloudFormationTemplate,
 		},
 		manifest:   conf.Manifest,
-		parser:     parser,
+		parser:     fs,
 		albEnabled: !conf.Manifest.RoutingRule.IsEmpty(),
+		localCRs:   uploadableCRs(crs).convert(),
 	}
 
 	if len(conf.EnvManifest.HTTPConfig.Private.Certificates) != 0 {
@@ -87,7 +92,11 @@ func (s *BackendService) Template() (string, error) {
 	if err != nil {
 		return "", err
 	}
-	sidecars, err := convertSidecar(s.manifest.Sidecars)
+	exposedPorts, err := s.manifest.ExposedPorts()
+	if err != nil {
+		return "", fmt.Errorf("parse exposed ports in service manifest %s: %w", s.name, err)
+	}
+	sidecars, err := convertSidecars(s.manifest.Sidecars, exposedPorts.PortsForContainer)
 	if err != nil {
 		return "", fmt.Errorf("convert the sidecar configuration for service %s: %w", s.name, err)
 	}
@@ -140,56 +149,75 @@ func (s *BackendService) Template() (string, error) {
 	if s.manifest.Network.Connect.Enabled() {
 		scConfig = convertServiceConnect(s.manifest.Network.Connect)
 	}
-	targetContainer, targetContainerPort := s.httpLoadBalancerTarget()
+	targetContainer, targetContainerPort, err := s.manifest.HTTPLoadBalancerTarget()
+	if err != nil {
+		return "", err
+	}
+
 	content, err := s.parser.ParseBackendService(template.WorkloadOpts{
+		// Workload parameters.
 		AppName:            s.app,
 		EnvName:            s.env,
-		WorkloadName:       s.name,
-		SerializedManifest: string(s.rawManifest),
 		EnvVersion:         s.rc.EnvVersion,
+		SerializedManifest: string(s.rawManifest),
+		WorkloadType:       manifestinfo.BackendServiceType,
+		WorkloadName:       s.name,
 
-		Variables:          convertEnvVars(s.manifest.BackendServiceConfig.Variables),
-		Secrets:            convertSecrets(s.manifest.BackendServiceConfig.Secrets),
-		Aliases:            aliases,
-		HTTPSListener:      s.httpsEnabled,
-		HTTPRedirect:       s.httpsEnabled,
-		NestedStack:        addonsOutputs,
-		AddonsExtraParams:  addonsParams,
-		Sidecars:           sidecars,
-		Autoscaling:        autoscaling,
-		CapacityProviders:  capacityProviders,
-		DesiredCountOnSpot: desiredCountOnSpot,
-		ExecuteCommand:     convertExecuteCommand(&s.manifest.ExecuteCommand),
-		WorkloadType:       manifest.BackendServiceType,
-		HealthCheck:        convertContainerHealthCheck(s.manifest.BackendServiceConfig.ImageConfig.HealthCheck),
+		// Configuration for the main container.
+		EntryPoint:   entrypoint,
+		Command:      command,
+		HealthCheck:  convertContainerHealthCheck(s.manifest.BackendServiceConfig.ImageConfig.HealthCheck),
+		PortMappings: convertPortMappings(exposedPorts.PortsForContainer[s.name]),
+		Secrets:      convertSecrets(s.manifest.BackendServiceConfig.Secrets),
+		Variables:    convertEnvVars(s.manifest.BackendServiceConfig.Variables),
+
+		// Additional options that are common between **all** workload templates.
+		AddonsExtraParams:       addonsParams,
+		Autoscaling:             autoscaling,
+		CapacityProviders:       capacityProviders,
+		CredentialsParameter:    aws.StringValue(s.manifest.ImageConfig.Image.Credentials),
+		DeploymentConfiguration: convertDeploymentConfig(s.manifest.DeployConfig),
+		DesiredCountOnSpot:      desiredCountOnSpot,
+		DependsOn:               convertDependsOn(s.manifest.ImageConfig.Image.DependsOn),
+		DockerLabels:            s.manifest.ImageConfig.Image.DockerLabels,
+		ExecuteCommand:          convertExecuteCommand(&s.manifest.ExecuteCommand),
+		LogConfig:               convertLogging(s.manifest.Logging),
+		NestedStack:             addonsOutputs,
+		Network:                 convertNetworkConfig(s.manifest.Network),
+		Publish:                 publishers,
+		PermissionsBoundary:     s.permBound,
+		Platform:                convertPlatform(s.manifest.Platform),
+		Storage:                 convertStorageOpts(s.manifest.Name, s.manifest.Storage),
+
+		// ALB configs.
+		ALBEnabled:          s.albEnabled,
+		Aliases:             aliases,
+		AllowedSourceIps:    allowedSourceIPs,
+		DeregistrationDelay: deregistrationDelay,
+		HostedZoneAliases:   hostedZoneAliases,
+		HTTPSListener:       s.httpsEnabled,
+		HTTPRedirect:        s.httpsEnabled,
 		HTTPTargetContainer: template.HTTPTargetContainer{
-			Port: aws.StringValue(targetContainerPort),
-			Name: aws.StringValue(targetContainer),
+			Port: targetContainerPort,
+			Name: targetContainer,
 		},
+		HTTPHealthCheck: convertHTTPHealthCheck(&s.manifest.RoutingRule.HealthCheck),
+		HTTPVersion:     convertHTTPVersion(s.manifest.RoutingRule.ProtocolVersion),
+
+		// Custom Resource Config.
+		CustomResources: crs,
+
+		// Sidecar config.
+		Sidecars: sidecars,
+
+		// service connect and service discovery options.
 		ServiceConnect:           scConfig,
-		HTTPHealthCheck:          convertHTTPHealthCheck(&s.manifest.RoutingRule.HealthCheck),
-		DeregistrationDelay:      deregistrationDelay,
-		AllowedSourceIps:         allowedSourceIPs,
-		CustomResources:          crs,
-		LogConfig:                convertLogging(s.manifest.Logging),
-		DockerLabels:             s.manifest.ImageConfig.Image.DockerLabels,
-		Storage:                  convertStorageOpts(s.manifest.Name, s.manifest.Storage),
-		Network:                  convertNetworkConfig(s.manifest.Network),
-		DeploymentConfiguration:  convertDeploymentConfig(s.manifest.DeployConfig),
-		EntryPoint:               entrypoint,
-		Command:                  command,
-		DependsOn:                convertDependsOn(s.manifest.ImageConfig.Image.DependsOn),
-		CredentialsParameter:     aws.StringValue(s.manifest.ImageConfig.Image.Credentials),
 		ServiceDiscoveryEndpoint: s.rc.ServiceDiscoveryEndpoint,
-		Publish:                  publishers,
-		Platform:                 convertPlatform(s.manifest.Platform),
-		HTTPVersion:              convertHTTPVersion(s.manifest.RoutingRule.ProtocolVersion),
-		ALBEnabled:               s.albEnabled,
+
+		// Additional options for request driven web service templates.
 		Observability: template.ObservabilityOpts{
 			Tracing: strings.ToUpper(aws.StringValue(s.manifest.Observability.Tracing)),
 		},
-		HostedZoneAliases:   hostedZoneAliases,
-		PermissionsBoundary: s.permBound,
 	})
 	if err != nil {
 		return "", fmt.Errorf("parse backend service template: %w", err)
@@ -201,41 +229,20 @@ func (s *BackendService) Template() (string, error) {
 	return string(overriddenTpl), nil
 }
 
-func (s *BackendService) httpLoadBalancerTarget() (targetContainer *string, targetPort *string) {
-	// Route load balancer traffic to main container by default.
-	targetContainer = aws.String(s.name)
-	targetPort = aws.String(s.containerPort())
-
-	rrTarget := s.manifest.RoutingRule.GetTargetContainer()
-	if rrTarget != nil && *rrTarget != *targetContainer {
-		targetContainer = rrTarget
-		targetPort = s.manifest.Sidecars[aws.StringValue(targetContainer)].Port
-	}
-
-	return
-}
-
-func (s *BackendService) containerPort() string {
-	port := template.NoExposedContainerPort
-	if s.manifest.BackendServiceConfig.ImageConfig.Port != nil {
-		port = strconv.FormatUint(uint64(aws.Uint16Value(s.manifest.BackendServiceConfig.ImageConfig.Port)), 10)
-	}
-
-	return port
-}
-
 // Parameters returns the list of CloudFormation parameters used by the template.
 func (s *BackendService) Parameters() ([]*cloudformation.Parameter, error) {
 	params, err := s.ecsWkld.Parameters()
 	if err != nil {
 		return nil, err
 	}
-
-	targetContainer, targetPort := s.httpLoadBalancerTarget()
+	targetContainer, targetPort, err := s.manifest.HTTPLoadBalancerTarget()
+	if err != nil {
+		return nil, err
+	}
 	params = append(params, []*cloudformation.Parameter{
 		{
 			ParameterKey:   aws.String(WorkloadContainerPortParamKey),
-			ParameterValue: aws.String(s.containerPort()),
+			ParameterValue: aws.String(s.manifest.MainContainerPort()),
 		},
 		{
 			ParameterKey:   aws.String(WorkloadEnvFileARNParamKey),
@@ -243,11 +250,11 @@ func (s *BackendService) Parameters() ([]*cloudformation.Parameter, error) {
 		},
 		{
 			ParameterKey:   aws.String(WorkloadTargetContainerParamKey),
-			ParameterValue: targetContainer,
+			ParameterValue: aws.String(targetContainer),
 		},
 		{
 			ParameterKey:   aws.String(WorkloadTargetPortParamKey),
-			ParameterValue: targetPort,
+			ParameterValue: aws.String(targetPort),
 		},
 	}...)
 
