@@ -9,7 +9,10 @@ import (
 	"testing"
 	"time"
 
+	"github.com/aws/copilot-cli/internal/pkg/template/templatetest"
+
 	"github.com/aws/copilot-cli/internal/pkg/config"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
@@ -33,6 +36,11 @@ var (
 )
 
 func TestBackendService_Template(t *testing.T) {
+	t.Cleanup(func() {
+		fs = realEmbedFS
+	})
+	fs = templatetest.Stub{}
+
 	t.Run("returns a wrapped error when addons template parsing fails", func(t *testing.T) {
 		// GIVEN
 		svc, err := NewBackendService(BackendServiceConfig{
@@ -75,7 +83,7 @@ func TestBackendService_Template(t *testing.T) {
 		require.EqualError(t, err, "parse addons parameters for api: some error")
 	})
 
-	t.Run("returns an error when failed to convert sidecar configuration", func(t *testing.T) {
+	t.Run("returns an error when failed to parse sidecar's exposed port", func(t *testing.T) {
 		// GIVEN
 		mft := manifest.NewBackendService(manifest.BackendServiceProps{
 			WorkloadProps: manifest.WorkloadProps{
@@ -101,7 +109,41 @@ func TestBackendService_Template(t *testing.T) {
 		_, err = svc.Template()
 
 		// THEN
-		require.EqualError(t, err, "convert the sidecar configuration for service api: cannot parse port mapping from 80/80/80")
+		require.EqualError(t, err, "parse exposed ports in service manifest api: cannot parse port mapping from 80/80/80")
+	})
+
+	t.Run("returns an error when failed to convert sidecar configuration", func(t *testing.T) {
+		// GIVEN
+		mft := manifest.NewBackendService(manifest.BackendServiceProps{
+			WorkloadProps: manifest.WorkloadProps{
+				Name:       "api",
+				Dockerfile: testDockerfile,
+			},
+			Port: 8080,
+		})
+		mft.Sidecars = map[string]*manifest.SidecarConfig{
+			"xray": {
+				Port: aws.String("80"),
+				ImageOverride: manifest.ImageOverride{
+					Command: manifest.CommandOverride{
+						String: aws.String("[bad'command]"),
+					},
+				},
+			},
+		}
+		svc, err := NewBackendService(BackendServiceConfig{
+			App:         &config.Application{},
+			EnvManifest: &manifest.Environment{},
+			Manifest:    mft,
+			Addons:      mockAddons{},
+		})
+		require.NoError(t, err)
+
+		// WHEN
+		_, err = svc.Template()
+
+		// THEN
+		require.EqualError(t, err, `convert the sidecar configuration for service api: convert "command" to string slice: convert string into tokens using shell-style rules: EOF found when expecting closing quote`)
 	})
 
 	t.Run("returns an error when failed to parse autoscaling template", func(t *testing.T) {
@@ -193,9 +235,10 @@ func TestBackendService_Template(t *testing.T) {
 			StringSlice: []string{"here"},
 		}
 		mft.ExecuteCommand = manifest.ExecuteCommand{Enable: aws.Bool(true)}
-		mft.DeployConfig = manifest.DeploymentConfiguration{
-			Rolling: aws.String("recreate"),
-		}
+		mft.DeployConfig = manifest.DeploymentConfig{
+			DeploymentControllerConfig: manifest.DeploymentControllerConfig{
+				Rolling: aws.String("recreate"),
+			}}
 		privatePlacement := manifest.PrivateSubnetPlacement
 		mft.Network.VPC.Placement = manifest.PlacementArgOrString{
 			PlacementString: &privatePlacement,
@@ -253,7 +296,7 @@ Outputs:
 			AppName:      "phonetool",
 			EnvName:      "test",
 			WorkloadName: "api",
-			WorkloadType: manifest.BackendServiceType,
+			WorkloadType: manifestinfo.BackendServiceType,
 			HealthCheck: &template.ContainerHealthCheck{
 				Command:     []string{"CMD-SHELL", "curl -f http://localhost/ || exit 1"},
 				Interval:    aws.Int64(5),
@@ -297,6 +340,13 @@ Outputs:
 			},
 			EntryPoint: []string{"enter", "from"},
 			Command:    []string{"here"},
+			PortMappings: []*template.PortMapping{
+				{
+					Protocol:      "tcp",
+					ContainerName: "api",
+					ContainerPort: 8080,
+				},
+			},
 		}, actual)
 	})
 
@@ -328,9 +378,10 @@ Outputs:
 			StringSlice: []string{"here"},
 		}
 		mft.ExecuteCommand = manifest.ExecuteCommand{Enable: aws.Bool(true)}
-		mft.DeployConfig = manifest.DeploymentConfiguration{
-			Rolling: aws.String("recreate"),
-		}
+		mft.DeployConfig = manifest.DeploymentConfig{
+			DeploymentControllerConfig: manifest.DeploymentControllerConfig{
+				Rolling: aws.String("recreate"),
+			}}
 		mft.RoutingRule = manifest.RoutingRuleConfiguration{
 			Path: aws.String("/albPath"),
 			HealthCheck: manifest.HealthCheckArgsOrString{
@@ -412,7 +463,7 @@ Outputs:
 			AppName:      "phonetool",
 			EnvName:      "test",
 			WorkloadName: "api",
-			WorkloadType: manifest.BackendServiceType,
+			WorkloadType: manifestinfo.BackendServiceType,
 			HealthCheck: &template.ContainerHealthCheck{
 				Command:     []string{"CMD-SHELL", "curl -f http://localhost/ || exit 1"},
 				Interval:    aws.Int64(5),
@@ -422,8 +473,15 @@ Outputs:
 			},
 			Sidecars: []*template.SidecarOpts{
 				{
-					Name: "envoy",
-					Port: aws.String("443"),
+					Name:  "envoy",
+					Image: aws.String(""),
+					PortMappings: []*template.PortMapping{
+						{
+							Protocol:      "tcp",
+							ContainerName: "envoy",
+							ContainerPort: 443,
+						},
+					},
 				},
 			},
 			HTTPTargetContainer: template.HTTPTargetContainer{
@@ -470,6 +528,13 @@ Outputs:
 			EntryPoint: []string{"enter", "from"},
 			Command:    []string{"here"},
 			ALBEnabled: true,
+			PortMappings: []*template.PortMapping{
+				{
+					Protocol:      "tcp",
+					ContainerName: "api",
+					ContainerPort: 8080,
+				},
+			},
 		}, actual)
 	})
 }
@@ -497,7 +562,9 @@ func TestBackendService_Parameters(t *testing.T) {
 				env:  testEnvName,
 				app:  testAppName,
 				image: manifest.Image{
-					Location: aws.String("mockLocation"),
+					ImageLocationOrBuild: manifest.ImageLocationOrBuild{
+						Location: aws.String("mockLocation"),
+					},
 				},
 			},
 			tc: testBackendSvcManifest.BackendServiceConfig.TaskConfig,
