@@ -7,10 +7,11 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/aws/copilot-cli/internal/pkg/deploy"
-
 	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/copilot-cli/internal/pkg/deploy"
+	"github.com/aws/copilot-cli/internal/pkg/deploy/upload/customresource"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 )
 
@@ -38,46 +39,46 @@ var awsSDKLayerForRegion = map[string]*string{
 	"me-south-1":     aws.String("arn:aws:lambda:me-south-1:507411403535:layer:AWSLambda-Node-AWS-SDK:10"),
 }
 
-type requestDrivenWebSvcReadParser interface {
-	template.ReadParser
-	ParseRequestDrivenWebService(template.WorkloadOpts) (*template.Content, error)
-}
-
 // RequestDrivenWebService represents the configuration needed to create a CloudFormation stack from a request-drive web service manifest.
 type RequestDrivenWebService struct {
 	*appRunnerWkld
 	manifest *manifest.RequestDrivenWebService
 	app      deploy.AppInformation
 
-	parser requestDrivenWebSvcReadParser
+	parser   requestDrivenWebSvcReadParser
+	localCRs []uploadable // Custom resources that have not been uploaded yet.
 }
 
 // RequestDrivenWebServiceConfig contains data required to initialize a request-driven web service stack.
 type RequestDrivenWebServiceConfig struct {
-	App         deploy.AppInformation
-	Env         string
-	Manifest    *manifest.RequestDrivenWebService
-	RawManifest []byte
-
-	RuntimeConfig RuntimeConfig
-	Addons        NestedStackConfigurer
+	App                deploy.AppInformation
+	Env                string
+	Manifest           *manifest.RequestDrivenWebService
+	RawManifest        []byte
+	ArtifactBucketName string
+	RuntimeConfig      RuntimeConfig
+	Addons             NestedStackConfigurer
 }
 
 // NewRequestDrivenWebService creates a new RequestDrivenWebService stack from a manifest file.
 func NewRequestDrivenWebService(cfg RequestDrivenWebServiceConfig) (*RequestDrivenWebService, error) {
-	parser := template.New()
+	crs, err := customresource.RDWS(fs)
+	if err != nil {
+		return nil, fmt.Errorf("request-driven web service custom resources: %w", err)
+	}
 	return &RequestDrivenWebService{
 		appRunnerWkld: &appRunnerWkld{
 			wkld: &wkld{
-				name:        aws.StringValue(cfg.Manifest.Name),
-				env:         cfg.Env,
-				app:         cfg.App.Name,
-				permBound:   cfg.App.PermissionsBoundary,
-				rc:          cfg.RuntimeConfig,
-				image:       cfg.Manifest.ImageConfig.Image,
-				rawManifest: cfg.RawManifest,
-				addons:      cfg.Addons,
-				parser:      parser,
+				name:               aws.StringValue(cfg.Manifest.Name),
+				env:                cfg.Env,
+				app:                cfg.App.Name,
+				permBound:          cfg.App.PermissionsBoundary,
+				artifactBucketName: cfg.ArtifactBucketName,
+				rc:                 cfg.RuntimeConfig,
+				image:              cfg.Manifest.ImageConfig.Image,
+				rawManifest:        cfg.RawManifest,
+				addons:             cfg.Addons,
+				parser:             fs,
 			},
 			instanceConfig:    cfg.Manifest.InstanceConfig,
 			imageConfig:       cfg.Manifest.ImageConfig,
@@ -85,7 +86,8 @@ func NewRequestDrivenWebService(cfg RequestDrivenWebServiceConfig) (*RequestDriv
 		},
 		app:      cfg.App,
 		manifest: cfg.Manifest,
-		parser:   parser,
+		parser:   fs,
+		localCRs: uploadableCRs(crs).convert(),
 	}, nil
 }
 
@@ -126,7 +128,7 @@ func (s *RequestDrivenWebService) Template() (string, error) {
 		NestedStack:          addonsOutputs,
 		AddonsExtraParams:    addonsParams,
 		EnableHealthCheck:    !s.healthCheckConfig.IsZero(),
-		WorkloadType:         manifest.RequestDrivenWebServiceType,
+		WorkloadType:         manifestinfo.RequestDrivenWebServiceType,
 		Alias:                s.manifest.Alias,
 		CustomResources:      crs,
 		AWSSDKLayer:          layerARN,
@@ -144,6 +146,7 @@ func (s *RequestDrivenWebService) Template() (string, error) {
 		Private:              aws.BoolValue(s.manifest.Private.Basic) || s.manifest.Private.Advanced.Endpoint != nil,
 		AppRunnerVPCEndpoint: s.manifest.Private.Advanced.Endpoint,
 		Count:                s.manifest.Count,
+		Secrets:              convertSecrets(s.manifest.RequestDrivenWebServiceConfig.Secrets),
 	})
 	if err != nil {
 		return "", err
