@@ -9,9 +9,13 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/aws/copilot-cli/internal/pkg/addon"
+	"github.com/aws/copilot-cli/internal/pkg/template/templatetest"
+
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 
+	"github.com/aws/copilot-cli/internal/pkg/addon"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
+
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack/mocks"
@@ -28,7 +32,7 @@ var (
 var testRDWebServiceManifest = &manifest.RequestDrivenWebService{
 	Workload: manifest.Workload{
 		Name: aws.String(testServiceName),
-		Type: aws.String(manifest.RequestDrivenWebServiceType),
+		Type: aws.String(manifestinfo.RequestDrivenWebServiceType),
 	},
 	RequestDrivenWebServiceConfig: manifest.RequestDrivenWebServiceConfig{
 		ImageConfig: manifest.ImageWithPort{
@@ -42,6 +46,7 @@ var testRDWebServiceManifest = &manifest.RequestDrivenWebService{
 			"LOG_LEVEL": {},
 			"NODE_ENV":  {},
 		},
+		Secrets: map[string]manifest.Secret{"foo": {}},
 		RequestDrivenWebServiceHttpConfig: manifest.RequestDrivenWebServiceHttpConfig{
 			HealthCheckConfiguration: manifest.HealthCheckArgsOrString{
 				Union: manifest.BasicToUnion[string, manifest.HTTPHealthCheckArgs]("/"),
@@ -54,6 +59,11 @@ var testRDWebServiceManifest = &manifest.RequestDrivenWebService{
 }
 
 func TestRequestDrivenWebService_NewRequestDrivenWebService(t *testing.T) {
+	t.Cleanup(func() {
+		fs = realEmbedFS
+	})
+	fs = templatetest.Stub{}
+
 	type testInput struct {
 		mft     *manifest.RequestDrivenWebService
 		env     string
@@ -128,7 +138,6 @@ func TestRequestDrivenWebService_NewRequestDrivenWebService(t *testing.T) {
 			require.Equal(t, tc.wantedStack.instanceConfig, stack.instanceConfig)
 			require.Equal(t, tc.wantedStack.imageConfig, stack.imageConfig)
 			require.NotNil(t, stack.addons)
-			require.NotNil(t, stack.parser)
 		})
 	}
 }
@@ -170,11 +179,12 @@ func TestRequestDrivenWebService_Template(t *testing.T) {
 						AppName:      "phonetool",
 						EnvName:      "test",
 						WorkloadName: "frontend",
-						WorkloadType: manifest.RequestDrivenWebServiceType,
+						WorkloadType: manifestinfo.RequestDrivenWebServiceType,
 						Variables: map[string]template.Variable{
 							"LOG_LEVEL": template.PlainVariable(""),
 							"NODE_ENV":  template.PlainVariable(""),
 						},
+						Secrets:           map[string]template.Secret{"foo": template.SecretFromPlainSSMOrARN("")},
 						Tags:              c.manifest.Tags,
 						Count:             c.manifest.Count,
 						EnableHealthCheck: true,
@@ -207,8 +217,9 @@ func TestRequestDrivenWebService_Template(t *testing.T) {
 						AppName:                  "phonetool",
 						EnvName:                  "test",
 						WorkloadName:             "frontend",
-						WorkloadType:             manifest.RequestDrivenWebServiceType,
+						WorkloadType:             manifestinfo.RequestDrivenWebServiceType,
 						Variables:                convertEnvVars(c.manifest.Variables),
+						Secrets:                  convertSecrets(c.manifest.RequestDrivenWebServiceConfig.Secrets),
 						Tags:                     c.manifest.Tags,
 						ServiceDiscoveryEndpoint: mockSD,
 						EnableHealthCheck:        true,
@@ -251,8 +262,9 @@ Outputs:
 						AppName:                  "phonetool",
 						EnvName:                  "test",
 						WorkloadName:             "frontend",
-						WorkloadType:             manifest.RequestDrivenWebServiceType,
+						WorkloadType:             manifestinfo.RequestDrivenWebServiceType,
 						Variables:                convertEnvVars(c.manifest.Variables),
+						Secrets:                  convertSecrets(c.manifest.RequestDrivenWebServiceConfig.Secrets),
 						Tags:                     c.manifest.Tags,
 						ServiceDiscoveryEndpoint: mockSD,
 						NestedStack: &template.WorkloadNestedStackOpts{
@@ -354,8 +366,12 @@ func TestRequestDrivenWebService_Parameters(t *testing.T) {
 	}{
 		"all required fields specified": {
 			imageConfig: manifest.ImageWithPort{
-				Image: manifest.Image{Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest")},
-				Port:  aws.Uint16(80),
+				Image: manifest.Image{
+					ImageLocationOrBuild: manifest.ImageLocationOrBuild{
+						Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest"),
+					},
+				},
+				Port: aws.Uint16(80),
 			},
 			instanceConfig: manifest.AppRunnerInstanceConfig{
 				CPU:    aws.Int(1024),
@@ -392,7 +408,11 @@ func TestRequestDrivenWebService_Parameters(t *testing.T) {
 		},
 		"error when port unspecified": {
 			imageConfig: manifest.ImageWithPort{
-				Image: manifest.Image{Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest")},
+				Image: manifest.Image{
+					ImageLocationOrBuild: manifest.ImageLocationOrBuild{
+						Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest"),
+					},
+				},
 			},
 			instanceConfig: manifest.AppRunnerInstanceConfig{
 				CPU:    aws.Int(1024),
@@ -402,8 +422,12 @@ func TestRequestDrivenWebService_Parameters(t *testing.T) {
 		},
 		"error when CPU unspecified": {
 			imageConfig: manifest.ImageWithPort{
-				Port:  aws.Uint16(80),
-				Image: manifest.Image{Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest")},
+				Port: aws.Uint16(80),
+				Image: manifest.Image{
+					ImageLocationOrBuild: manifest.ImageLocationOrBuild{
+						Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest"),
+					},
+				},
 			},
 			instanceConfig: manifest.AppRunnerInstanceConfig{
 				Memory: aws.Int(1024),
@@ -412,8 +436,12 @@ func TestRequestDrivenWebService_Parameters(t *testing.T) {
 		},
 		"error when memory unspecified": {
 			imageConfig: manifest.ImageWithPort{
-				Port:  aws.Uint16(80),
-				Image: manifest.Image{Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest")},
+				Port: aws.Uint16(80),
+				Image: manifest.Image{
+					ImageLocationOrBuild: manifest.ImageLocationOrBuild{
+						Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest"),
+					},
+				},
 			},
 			instanceConfig: manifest.AppRunnerInstanceConfig{
 				CPU: aws.Int(1024),
