@@ -12,6 +12,8 @@ import (
 	"strings"
 	"time"
 
+	"github.com/aws/copilot-cli/internal/pkg/deploy/upload/customresource"
+
 	"github.com/aws/copilot-cli/internal/pkg/aws/partitions"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/template/override"
@@ -66,8 +68,21 @@ var (
 	}
 )
 
-// convertSidecar converts the manifest sidecar configuration into a format parsable by the templates pkg.
-func convertSidecar(s map[string]*manifest.SidecarConfig) ([]*template.SidecarOpts, error) {
+func convertPortMappings(exposedPorts []manifest.ExposedPort) []*template.PortMapping {
+	portMapping := make([]*template.PortMapping, len(exposedPorts))
+	for idx, exposedPort := range exposedPorts {
+		portMapping[idx] = &template.PortMapping{
+			ContainerPort: exposedPort.Port,
+			Protocol:      exposedPort.Protocol,
+			ContainerName: exposedPort.ContainerName,
+		}
+	}
+	return portMapping
+}
+
+// convertSidecars converts the manifest sidecar configuration into a format parsable by the templates pkg.
+func convertSidecars(s map[string]*manifest.SidecarConfig, exposedPorts map[string][]manifest.ExposedPort) ([]*template.SidecarOpts, error) {
+	var sidecars []*template.SidecarOpts
 	if s == nil {
 		return nil, nil
 	}
@@ -78,14 +93,9 @@ func convertSidecar(s map[string]*manifest.SidecarConfig) ([]*template.SidecarOp
 		keys = append(keys, k)
 	}
 	sort.Strings(keys)
-
-	var sidecars []*template.SidecarOpts
 	for _, name := range keys {
 		config := s[name]
-		port, protocol, err := manifest.ParsePortMapping(config.Port)
-		if err != nil {
-			return nil, err
-		}
+		imageURI, _ := config.ImageURI()
 		entrypoint, err := convertEntryPoint(config.EntryPoint)
 		if err != nil {
 			return nil, err
@@ -97,10 +107,8 @@ func convertSidecar(s map[string]*manifest.SidecarConfig) ([]*template.SidecarOp
 		mp := convertSidecarMountPoints(config.MountPoints)
 		sidecars = append(sidecars, &template.SidecarOpts{
 			Name:       name,
-			Image:      config.Image,
+			Image:      aws.String(imageURI),
 			Essential:  config.Essential,
-			Port:       port,
-			Protocol:   protocol,
 			CredsParam: config.CredsParam,
 			Secrets:    convertSecrets(config.Secrets),
 			Variables:  convertEnvVars(config.Variables),
@@ -112,6 +120,7 @@ func convertSidecar(s map[string]*manifest.SidecarConfig) ([]*template.SidecarOp
 			EntryPoint:   entrypoint,
 			HealthCheck:  convertContainerHealthCheck(config.HealthCheck),
 			Command:      command,
+			PortMappings: convertPortMappings(exposedPorts[name]),
 		})
 	}
 	return sidecars, nil
@@ -360,6 +369,24 @@ func convertHTTPHealthCheck(hc *manifest.HealthCheckArgsOrString) template.HTTPH
 	return opts
 }
 
+// convertNLBHealthCheck converts the NLB health check configuration into a format parsable by the templates pkg.
+func convertNLBHealthCheck(nlbHC *manifest.NLBHealthCheckArgs) template.NLBHealthCheck {
+	hc := template.NLBHealthCheck{
+		HealthyThreshold:   nlbHC.HealthyThreshold,
+		UnhealthyThreshold: nlbHC.UnhealthyThreshold,
+	}
+	if nlbHC.Port != nil {
+		hc.Port = strconv.Itoa(aws.IntValue(nlbHC.Port))
+	}
+	if nlbHC.Timeout != nil {
+		hc.Timeout = aws.Int64(int64(nlbHC.Timeout.Seconds()))
+	}
+	if nlbHC.Interval != nil {
+		hc.Interval = aws.Int64(int64(nlbHC.Interval.Seconds()))
+	}
+	return hc
+}
+
 type networkLoadBalancerConfig struct {
 	settings *template.NetworkLoadBalancer
 
@@ -439,69 +466,46 @@ func (s *LoadBalancedWebService) convertNetworkLoadBalancer() (networkLoadBalanc
 		return networkLoadBalancerConfig{}, nil
 	}
 
+	// Parse targetContainer and targetPort for the Network Load Balancer targets.
+	targetContainer, targetPort, err := s.manifest.NetworkLoadBalancerTarget()
+	if err != nil {
+		return networkLoadBalancerConfig{}, err
+	}
+
 	// Parse listener port and protocol.
 	port, protocol, err := manifest.ParsePortMapping(nlbConfig.Port)
 	if err != nil {
 		return networkLoadBalancerConfig{}, err
 	}
+
 	if protocol == nil {
 		protocol = aws.String(defaultNLBProtocol)
 	}
 
-	// Configure target container and port.
-	targetContainer := s.name
-	if nlbConfig.TargetContainer != nil {
-		targetContainer = aws.StringValue(nlbConfig.TargetContainer)
-	}
-
-	// By default, the target port is the same as listener port.
-	targetPort := aws.StringValue(port)
-	if targetContainer != s.name {
-		// If the target container is a sidecar container, the target port is the exposed sidecar port.
-		sideCarPort := s.manifest.Sidecars[targetContainer].Port // We validated that a sidecar container exposes a port if it is a target container.
-		port, _, err := manifest.ParsePortMapping(sideCarPort)
-		if err != nil {
-			return networkLoadBalancerConfig{}, err
-		}
-		targetPort = aws.StringValue(port)
-	}
-	// Finally, if a target port is explicitly specified, use that value.
-	if nlbConfig.TargetPort != nil {
-		targetPort = strconv.Itoa(aws.IntValue(nlbConfig.TargetPort))
-	}
-
 	aliases, err := convertAlias(nlbConfig.Aliases)
 	if err != nil {
 		return networkLoadBalancerConfig{}, fmt.Errorf(`convert "nlb.alias" to string slice: %w`, err)
 	}
 
-	hc := template.NLBHealthCheck{
-		HealthyThreshold:   nlbConfig.HealthCheck.HealthyThreshold,
-		UnhealthyThreshold: nlbConfig.HealthCheck.UnhealthyThreshold,
-	}
-	if nlbConfig.HealthCheck.Port != nil {
-		hc.Port = strconv.Itoa(aws.IntValue(nlbConfig.HealthCheck.Port))
-	}
-	if nlbConfig.HealthCheck.Timeout != nil {
-		hc.Timeout = aws.Int64(int64(nlbConfig.HealthCheck.Timeout.Seconds()))
-	}
-	if nlbConfig.HealthCheck.Interval != nil {
-		hc.Interval = aws.Int64(int64(nlbConfig.HealthCheck.Interval.Seconds()))
-	}
+	hc := convertNLBHealthCheck(&nlbConfig.HealthCheck)
+
 	config := networkLoadBalancerConfig{
 		settings: &template.NetworkLoadBalancer{
 			PublicSubnetCIDRs: s.publicSubnetCIDRBlocks,
-			Listener: template.NetworkLoadBalancerListener{
-				Port:            aws.StringValue(port),
-				Protocol:        strings.ToUpper(aws.StringValue(protocol)),
-				TargetContainer: targetContainer,
-				TargetPort:      targetPort,
-				SSLPolicy:       nlbConfig.SSLPolicy,
-				Aliases:         aliases,
-				HealthCheck:     hc,
-				Stickiness:      nlbConfig.Stickiness,
+			Listener: []template.NetworkLoadBalancerListener{
+				{
+					Port:            aws.StringValue(port),
+					Protocol:        strings.ToUpper(aws.StringValue(protocol)),
+					TargetContainer: targetContainer,
+					TargetPort:      targetPort,
+					SSLPolicy:       nlbConfig.SSLPolicy,
+					Aliases:         aliases,
+					HealthCheck:     hc,
+					Stickiness:      nlbConfig.Stickiness,
+				},
 			},
-			MainContainerPort: s.containerPort(),
+			MainContainerPort:   s.manifest.MainContainerPort(),
+			CertificateRequired: strings.ToUpper(aws.StringValue(protocol)) == manifest.TLS,
 		},
 	}
 
@@ -812,17 +816,11 @@ func convertEntryPoint(entrypoint manifest.EntryPointOverride) ([]string, error)
 	return out, nil
 }
 
-func convertDeploymentConfig(in manifest.DeploymentConfiguration) template.DeploymentConfigurationOpts {
+func convertDeploymentControllerConfig(in manifest.DeploymentControllerConfig) template.DeploymentConfigurationOpts {
 	out := template.DeploymentConfigurationOpts{
 		MinHealthyPercent: minHealthyPercentDefault,
 		MaxPercent:        maxPercentDefault,
-		Rollback: template.RollingUpdateRollbackConfig{
-			AlarmNames:        in.RollbackAlarms.Basic,
-			CPUUtilization:    in.RollbackAlarms.Advanced.CPUUtilization,
-			MemoryUtilization: in.RollbackAlarms.Advanced.MemoryUtilization,
-		},
 	}
-
 	if strings.EqualFold(aws.StringValue(in.Rolling), manifest.ECSRecreateRollingUpdateStrategy) {
 		out.MinHealthyPercent = minHealthyPercentRecreate
 		out.MaxPercent = maxPercentRecreate
@@ -830,6 +828,27 @@ func convertDeploymentConfig(in manifest.DeploymentConfiguration) template.Deplo
 	return out
 }
 
+func convertDeploymentConfig(in manifest.DeploymentConfig) template.DeploymentConfigurationOpts {
+	out := convertDeploymentControllerConfig(in.DeploymentControllerConfig)
+	out.Rollback = template.RollingUpdateRollbackConfig{
+		AlarmNames:        in.RollbackAlarms.Basic,
+		CPUUtilization:    in.RollbackAlarms.Advanced.CPUUtilization,
+		MemoryUtilization: in.RollbackAlarms.Advanced.MemoryUtilization,
+	}
+	return out
+}
+
+func convertWorkerDeploymentConfig(in manifest.WorkerDeploymentConfig) template.DeploymentConfigurationOpts {
+	out := convertDeploymentControllerConfig(in.DeploymentControllerConfig)
+	out.Rollback = template.RollingUpdateRollbackConfig{
+		AlarmNames:        in.WorkerRollbackAlarms.Basic,
+		CPUUtilization:    in.WorkerRollbackAlarms.Advanced.CPUUtilization,
+		MemoryUtilization: in.WorkerRollbackAlarms.Advanced.MemoryUtilization,
+		MessagesDelayed:   in.WorkerRollbackAlarms.Advanced.MessagesDelayed,
+	}
+	return out
+}
+
 func convertCommand(command manifest.CommandOverride) ([]string, error) {
 	out, err := command.ToStringSlice()
 	if err != nil {
@@ -1081,3 +1100,13 @@ func convertCustomResources(urlForFunc map[string]string) (map[string]template.S
 	}
 	return out, nil
 }
+
+type uploadableCRs []*customresource.CustomResource
+
+func (in uploadableCRs) convert() []uploadable {
+	out := make([]uploadable, len(in))
+	for i, cr := range in {
+		out[i] = cr
+	}
+	return out
+}
