@@ -22,8 +22,16 @@ func Test_convertSidecar(t *testing.T) {
 	mockMap := map[string]template.Variable{"foo": template.PlainVariable("")}
 	mockSecrets := map[string]template.Secret{"foo": template.SecretFromPlainSSMOrARN("")}
 	mockCredsParam := aws.String("mockCredsParam")
+	mockExposedPorts := map[string][]manifest.ExposedPort{
+		"foo": {
+			{
+				Protocol:      "tcp",
+				ContainerName: "foo",
+				Port:          uint16(2000),
+			},
+		},
+	}
 	testCases := map[string]struct {
-		inPort            *string
 		inEssential       bool
 		inLabels          map[string]string
 		inDependsOn       map[string]string
@@ -34,42 +42,45 @@ func Test_convertSidecar(t *testing.T) {
 		wanted    *template.SidecarOpts
 		wantedErr error
 	}{
-		"invalid port": {
-			inPort: aws.String("b/a/d/P/o/r/t"),
-
-			wantedErr: fmt.Errorf("cannot parse port mapping from b/a/d/P/o/r/t"),
-		},
 		"good port without protocol": {
-			inPort:      aws.String("2000"),
 			inEssential: true,
 
 			wanted: &template.SidecarOpts{
 				Name:       "foo",
-				Port:       aws.String("2000"),
 				CredsParam: mockCredsParam,
 				Image:      mockImage,
 				Secrets:    mockSecrets,
 				Variables:  mockMap,
 				Essential:  aws.Bool(true),
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"good port with protocol": {
-			inPort:      aws.String("2000/udp"),
 			inEssential: true,
 
 			wanted: &template.SidecarOpts{
 				Name:       "foo",
-				Port:       aws.String("2000"),
-				Protocol:   aws.String("udp"),
 				CredsParam: mockCredsParam,
 				Image:      mockImage,
 				Secrets:    mockSecrets,
 				Variables:  mockMap,
 				Essential:  aws.Bool(true),
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"good container dependencies": {
-			inPort:      aws.String("2000"),
 			inEssential: true,
 			inDependsOn: map[string]string{
 				"frontend": "start",
@@ -77,7 +88,6 @@ func Test_convertSidecar(t *testing.T) {
 
 			wanted: &template.SidecarOpts{
 				Name:       "foo",
-				Port:       aws.String("2000"),
 				CredsParam: mockCredsParam,
 				Image:      mockImage,
 				Secrets:    mockSecrets,
@@ -86,10 +96,16 @@ func Test_convertSidecar(t *testing.T) {
 				DependsOn: map[string]string{
 					"frontend": "START",
 				},
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"specify essential as false": {
-			inPort:      aws.String("2000"),
 			inEssential: false,
 			inLabels: map[string]string{
 				"com.amazonaws.ecs.copilot.sidecar.description": "wow",
@@ -97,7 +113,6 @@ func Test_convertSidecar(t *testing.T) {
 
 			wanted: &template.SidecarOpts{
 				Name:       "foo",
-				Port:       aws.String("2000"),
 				CredsParam: mockCredsParam,
 				Image:      mockImage,
 				Secrets:    mockSecrets,
@@ -106,6 +121,13 @@ func Test_convertSidecar(t *testing.T) {
 				DockerLabels: map[string]string{
 					"com.amazonaws.ecs.copilot.sidecar.description": "wow",
 				},
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"do not specify image override": {
@@ -118,6 +140,13 @@ func Test_convertSidecar(t *testing.T) {
 				Essential:  aws.Bool(false),
 				EntryPoint: nil,
 				Command:    nil,
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"specify entrypoint as a string": {
@@ -134,6 +163,13 @@ func Test_convertSidecar(t *testing.T) {
 				Essential:  aws.Bool(false),
 				EntryPoint: []string{"bin"},
 				Command:    nil,
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"specify entrypoint as a string slice": {
@@ -150,6 +186,13 @@ func Test_convertSidecar(t *testing.T) {
 				Essential:  aws.Bool(false),
 				EntryPoint: []string{"bin", "arg"},
 				Command:    nil,
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"specify command as a string": {
@@ -166,6 +209,13 @@ func Test_convertSidecar(t *testing.T) {
 				Essential:  aws.Bool(false),
 				EntryPoint: nil,
 				Command:    []string{"arg"},
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"specify command as a string slice": {
@@ -182,6 +232,13 @@ func Test_convertSidecar(t *testing.T) {
 				Essential:  aws.Bool(false),
 				EntryPoint: nil,
 				Command:    []string{"arg1", "arg2"},
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 		"with health check": {
@@ -203,6 +260,13 @@ func Test_convertSidecar(t *testing.T) {
 					StartPeriod: aws.Int64(0),
 					Timeout:     aws.Int64(5),
 				},
+				PortMappings: []*template.PortMapping{
+					{
+						Protocol:      "tcp",
+						ContainerName: "foo",
+						ContainerPort: uint16(2000),
+					},
+				},
 			},
 		},
 	}
@@ -211,18 +275,17 @@ func Test_convertSidecar(t *testing.T) {
 			sidecar := map[string]*manifest.SidecarConfig{
 				"foo": {
 					CredsParam:    mockCredsParam,
-					Image:         mockImage,
+					Image:         manifest.Union[*string, manifest.ImageLocationOrBuild]{Basic: mockImage},
 					Secrets:       map[string]manifest.Secret{"foo": {}},
 					Variables:     map[string]manifest.Variable{"foo": {}},
 					Essential:     aws.Bool(tc.inEssential),
-					Port:          tc.inPort,
 					DockerLabels:  tc.inLabels,
 					DependsOn:     tc.inDependsOn,
 					ImageOverride: tc.inImageOverride,
 					HealthCheck:   tc.inHealthCheck,
 				},
 			}
-			got, err := convertSidecar(sidecar)
+			got, err := convertSidecars(sidecar, mockExposedPorts)
 
 			if tc.wantedErr != nil {
 				require.EqualError(t, err, tc.wantedErr.Error())
@@ -2055,36 +2118,38 @@ func Test_convertSubscribe(t *testing.T) {
 
 func Test_convertDeploymentConfig(t *testing.T) {
 	testCases := map[string]struct {
-		in  manifest.DeploymentConfiguration
+		in  manifest.DeploymentConfig
 		out template.DeploymentConfigurationOpts
 	}{
 		"if 'recreate' strategy indicated, populate with replacement defaults": {
-			in: manifest.DeploymentConfiguration{
-				Rolling: aws.String("recreate"),
-			},
+			in: manifest.DeploymentConfig{
+				DeploymentControllerConfig: manifest.DeploymentControllerConfig{
+					Rolling: aws.String("recreate"),
+				}},
 			out: template.DeploymentConfigurationOpts{
 				MinHealthyPercent: minHealthyPercentRecreate,
 				MaxPercent:        maxPercentRecreate,
 			},
 		},
 		"if 'default' strategy indicated, populate with rolling defaults": {
-			in: manifest.DeploymentConfiguration{
-				Rolling: aws.String("default"),
-			},
+			in: manifest.DeploymentConfig{
+				DeploymentControllerConfig: manifest.DeploymentControllerConfig{
+					Rolling: aws.String("default"),
+				}},
 			out: template.DeploymentConfigurationOpts{
 				MinHealthyPercent: minHealthyPercentDefault,
 				MaxPercent:        maxPercentDefault,
 			},
 		},
 		"if nothing indicated, populate with rolling defaults": {
-			in: manifest.DeploymentConfiguration{},
+			in: manifest.DeploymentConfig{},
 			out: template.DeploymentConfigurationOpts{
 				MinHealthyPercent: minHealthyPercentDefault,
 				MaxPercent:        maxPercentDefault,
 			},
 		},
 		"if alarm names entered, format and populate": {
-			in: manifest.DeploymentConfiguration{
+			in: manifest.DeploymentConfig{
 				RollbackAlarms: manifest.BasicToUnion[[]string, manifest.AlarmArgs](
 					[]string{"alarmName1", "alarmName2"}),
 			},
@@ -2097,7 +2162,7 @@ func Test_convertDeploymentConfig(t *testing.T) {
 			},
 		},
 		"if alarm args entered, transform": {
-			in: manifest.DeploymentConfiguration{
+			in: manifest.DeploymentConfig{
 				RollbackAlarms: manifest.AdvancedToUnion[[]string, manifest.AlarmArgs](
 					manifest.AlarmArgs{
 						CPUUtilization:    aws.Float64(34),
@@ -2121,6 +2186,53 @@ func Test_convertDeploymentConfig(t *testing.T) {
 	}
 }
 
+func Test_convertWorkerDeploymentConfig(t *testing.T) {
+	testCases := map[string]struct {
+		in  manifest.WorkerDeploymentConfig
+		out template.DeploymentConfigurationOpts
+	}{
+		"if alarm names entered, format and populate": {
+			in: manifest.WorkerDeploymentConfig{
+				WorkerRollbackAlarms: manifest.BasicToUnion[[]string, manifest.WorkerAlarmArgs](
+					[]string{"alarmName1", "alarmName2"}),
+			},
+			out: template.DeploymentConfigurationOpts{
+				MinHealthyPercent: minHealthyPercentDefault,
+				MaxPercent:        maxPercentDefault,
+				Rollback: template.RollingUpdateRollbackConfig{
+					AlarmNames: []string{"alarmName1", "alarmName2"},
+				},
+			},
+		},
+		"if alarm args entered, transform": {
+			in: manifest.WorkerDeploymentConfig{
+				WorkerRollbackAlarms: manifest.AdvancedToUnion[[]string, manifest.WorkerAlarmArgs](
+					manifest.WorkerAlarmArgs{
+						AlarmArgs: manifest.AlarmArgs{
+							CPUUtilization:    aws.Float64(34),
+							MemoryUtilization: aws.Float64(56),
+						},
+						MessagesDelayed: aws.Int(10),
+					}),
+			},
+			out: template.DeploymentConfigurationOpts{
+				MinHealthyPercent: minHealthyPercentDefault,
+				MaxPercent:        maxPercentDefault,
+				Rollback: template.RollingUpdateRollbackConfig{
+					CPUUtilization:    aws.Float64(34),
+					MemoryUtilization: aws.Float64(56),
+					MessagesDelayed:   aws.Int(10),
+				},
+			},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			require.Equal(t, tc.out, convertWorkerDeploymentConfig(tc.in))
+		})
+	}
+}
+
 func Test_convertPlatform(t *testing.T) {
 	testCases := map[string]struct {
 		in  manifest.PlatformArgsOrString
