@@ -18,7 +18,11 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/ecs"
 )
 
-const fmtAppRunnerSvcLogGroupName = "/aws/apprunner/%s/%s/service"
+const (
+	fmtAppRunnerSvcLogGroupName = "/aws/apprunner/%s/%s/service"
+	autoscalingAlarmType        = "Auto Scaling"
+	rollbackAlarmType           = "Rollback"
+)
 
 type targetHealthGetter interface {
 	TargetsHealth(targetGroupARN string) ([]*elbv2.TargetHealth, error)
@@ -26,7 +30,7 @@ type targetHealthGetter interface {
 
 type alarmStatusGetter interface {
 	AlarmsWithTags(tags map[string]string) ([]cloudwatch.AlarmStatus, error)
-	AlarmStatus(alarms []string) ([]cloudwatch.AlarmStatus, error)
+	AlarmStatuses(...cloudwatch.DescribeAlarmOpts) ([]cloudwatch.AlarmStatus, error)
 }
 
 type logGetter interface {
@@ -146,8 +150,8 @@ func (s *ecsStatusDescriber) Describe() (HumanJSONStringer, error) {
 		}
 		stoppedTaskStatus = append(stoppedTaskStatus, *status)
 	}
-
-	var alarms []cloudwatch.AlarmStatus
+	// Using a map then converting it to a slice to avoid duplication.
+	alarms := make(map[string]cloudwatch.AlarmStatus)
 	taggedAlarms, err := s.cwSvcGetter.AlarmsWithTags(map[string]string{
 		deploy.AppTagKey:     s.app,
 		deploy.EnvTagKey:     s.env,
@@ -156,13 +160,32 @@ func (s *ecsStatusDescriber) Describe() (HumanJSONStringer, error) {
 	if err != nil {
 		return nil, fmt.Errorf("get tagged CloudWatch alarms: %w", err)
 	}
-	alarms = append(alarms, taggedAlarms...)
+	for _, alarm := range taggedAlarms {
+		alarms[alarm.Name] = alarm
+	}
 	autoscalingAlarms, err := s.ecsServiceAutoscalingAlarms(svcDesc.ClusterName, svcDesc.Name)
 	if err != nil {
 		return nil, err
 	}
-	alarms = append(alarms, autoscalingAlarms...)
-
+	for _, alarm := range autoscalingAlarms {
+		alarms[alarm.Name] = alarm
+	}
+	rollbackAlarms, err := s.ecsServiceRollbackAlarms(s.app, s.env, s.svc)
+	if err != nil {
+		return nil, err
+	}
+	for _, alarm := range rollbackAlarms {
+		alarms[alarm.Name] = alarm
+	}
+	alarmList := make([]cloudwatch.AlarmStatus, len(alarms))
+	var i int
+	for _, v := range alarms {
+		alarmList[i] = v
+		i++
+	}
+	// Sort by alarm type, then alarm name within type categories.
+	sort.SliceStable(alarmList, func(i, j int) bool { return alarmList[i].Name < alarmList[j].Name})
+	sort.SliceStable(alarmList, func(i, j int) bool { return alarmList[i].Type < alarmList[j].Type})
 	var tasksTargetHealth []taskTargetHealth
 	targetGroupsARN := service.TargetGroups()
 	for _, groupARN := range targetGroupsARN {
@@ -182,7 +205,7 @@ func (s *ecsStatusDescriber) Describe() (HumanJSONStringer, error) {
 	return &ecsServiceStatus{
 		Service:                  service.ServiceStatus(),
 		DesiredRunningTasks:      taskStatus,
-		Alarms:                   alarms,
+		Alarms:                   alarmList,
 		StoppedTasks:             stoppedTaskStatus,
 		TargetHealthDescriptions: tasksTargetHealth,
 	}, nil
@@ -193,10 +216,28 @@ func (s *ecsStatusDescriber) ecsServiceAutoscalingAlarms(cluster, service string
 	if err != nil {
 		return nil, fmt.Errorf("retrieve auto scaling alarm names for ECS service %s/%s: %w", cluster, service, err)
 	}
-	alarms, err := s.cwSvcGetter.AlarmStatus(alarmNames)
+	if len(alarmNames) == 0 {
+		return nil, nil
+	}
+	alarms, err := s.cwSvcGetter.AlarmStatuses(cloudwatch.WithNames(alarmNames))
 	if err != nil {
 		return nil, fmt.Errorf("get auto scaling CloudWatch alarms: %w", err)
 	}
+	for i := range alarms {
+		alarms[i].Type = autoscalingAlarmType
+	}
+	return alarms, nil
+}
+
+func (s *ecsStatusDescriber) ecsServiceRollbackAlarms(app, env, svc string) ([]cloudwatch.AlarmStatus, error) {
+	// This will not fetch imported alarms, as we filter by the Copilot-generated prefix of alarm names. This will also not fetch Copilot-generated alarms with names exceeding 255 characters, due to the balanced truncating of `TruncateAlarmName`.
+	alarms, err := s.cwSvcGetter.AlarmStatuses(cloudwatch.WithPrefix(fmt.Sprintf("%s-%s-%s-CopilotRollback", app, env, svc)))
+	if err != nil {
+		return nil, fmt.Errorf("get Copilot-created CloudWatch alarms: %w", err)
+	}
+	for i := range alarms {
+		alarms[i].Type = rollbackAlarmType
+	}
 	return alarms, nil
 }
 
