@@ -6,7 +6,6 @@ package exec
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 )
@@ -18,7 +17,7 @@ const (
 // InstallLatestBinary installs the latest ssm plugin.
 func (s SSMPluginCommand) InstallLatestBinary() error {
 	if s.tempDir == "" {
-		dir, err := ioutil.TempDir("", "ssmplugin")
+		dir, err := os.MkdirTemp("", "ssmplugin")
 		if err != nil {
 			return fmt.Errorf("create a temporary directory: %w", err)
 		}
