@@ -12,6 +12,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/initialize/mocks"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
 )
@@ -36,7 +37,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 		wantedErr error
 	}{
 		"writes Scheduled Job manifest, and creates repositories successfully": {
-			inJobType:        manifest.ScheduledJobType,
+			inJobType:        manifestinfo.ScheduledJobType,
 			inAppName:        "app",
 			inJobName:        "resizer",
 			inDockerfilePath: "resizer/Dockerfile",
@@ -56,7 +57,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 						require.Equal(t, &config.Workload{
 							Name: "resizer",
 							App:  "app",
-							Type: manifest.ScheduledJobType,
+							Type: manifestinfo.ScheduledJobType,
 						}, app)
 					}).
 					Return(nil)
@@ -73,7 +74,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 			},
 		},
 		"using existing image": {
-			inJobType: manifest.ScheduledJobType,
+			inJobType: manifestinfo.ScheduledJobType,
 			inAppName: "app",
 			inJobName: "resizer",
 			inImage:   "mockImage",
@@ -83,7 +84,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 			mockWriter: func(m *mocks.MockWorkspace) {
 				m.EXPECT().Rel("/resizer/manifest.yml").Return("manifest.yml", nil)
 				m.EXPECT().WriteJobManifest(gomock.Any(), "resizer").Do(func(m *manifest.ScheduledJob, _ string) {
-					require.Equal(t, *m.Workload.Type, manifest.ScheduledJobType)
+					require.Equal(t, *m.Workload.Type, manifestinfo.ScheduledJobType)
 					require.Equal(t, *m.ImageConfig.Image.Location, "mockImage")
 				}).Return("/resizer/manifest.yml", nil)
 			},
@@ -93,7 +94,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 						require.Equal(t, &config.Workload{
 							Name: "resizer",
 							App:  "app",
-							Type: manifest.ScheduledJobType,
+							Type: manifestinfo.ScheduledJobType,
 						}, app)
 					}).
 					Return(nil)
@@ -110,7 +111,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 			},
 		},
 		"write manifest error": {
-			inJobType:        manifest.ScheduledJobType,
+			inJobType:        manifestinfo.ScheduledJobType,
 			inAppName:        "app",
 			inJobName:        "resizer",
 			inDockerfilePath: "resizer/Dockerfile",
@@ -125,7 +126,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 			wantedErr: errors.New("write job manifest: some error"),
 		},
 		"app error": {
-			inJobType:        manifest.ScheduledJobType,
+			inJobType:        manifestinfo.ScheduledJobType,
 			inAppName:        "app",
 			inJobName:        "resizer",
 			inDockerfilePath: "resizer/Dockerfile",
@@ -142,7 +143,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 			wantedErr: errors.New("get application app: some error"),
 		},
 		"add job to app fails": {
-			inJobType:        manifest.ScheduledJobType,
+			inJobType:        manifestinfo.ScheduledJobType,
 			inAppName:        "app",
 			inJobName:        "resizer",
 			inDockerfilePath: "frontend/Dockerfile",
@@ -165,7 +166,7 @@ func TestWorkloadInitializer_Job(t *testing.T) {
 			wantedErr: errors.New("add job resizer to application app: some error"),
 		},
 		"error saving app": {
-			inJobType:        manifest.ScheduledJobType,
+			inJobType:        manifestinfo.ScheduledJobType,
 			inAppName:        "app",
 			inJobName:        "resizer",
 			inDockerfilePath: "resizer/Dockerfile",
@@ -272,7 +273,7 @@ func TestAppInitOpts_createLoadBalancedAppManifest(t *testing.T) {
 				m.EXPECT().ListServices("app").Return([]*config.Workload{
 					{
 						Name: "frontend",
-						Type: manifest.LoadBalancedWebServiceType,
+						Type: manifestinfo.LoadBalancedWebServiceType,
 					},
 				}, nil)
 			},
@@ -306,7 +307,7 @@ func TestAppInitOpts_createLoadBalancedAppManifest(t *testing.T) {
 				m.EXPECT().ListServices("app").Return([]*config.Workload{
 					{
 						Name: "another-app",
-						Type: manifest.LoadBalancedWebServiceType,
+						Type: manifestinfo.LoadBalancedWebServiceType,
 					},
 				}, nil)
 			},
@@ -436,7 +437,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 		wantedErr error
 	}{
 		"writes Load Balanced Web Service manifest, and creates repositories successfully": {
-			inSvcType:        manifest.LoadBalancedWebServiceType,
+			inSvcType:        manifestinfo.LoadBalancedWebServiceType,
 			inAppName:        "app",
 			inSvcName:        "frontend",
 			inDockerfilePath: "frontend/Dockerfile",
@@ -456,7 +457,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 						require.Equal(t, &config.Workload{
 							Name: "frontend",
 							App:  "app",
-							Type: manifest.LoadBalancedWebServiceType,
+							Type: manifestinfo.LoadBalancedWebServiceType,
 						}, app)
 					}).
 					Return(nil)
@@ -473,7 +474,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			},
 		},
 		"app error": {
-			inSvcType:        manifest.LoadBalancedWebServiceType,
+			inSvcType:        manifestinfo.LoadBalancedWebServiceType,
 			inAppName:        "app",
 			inSvcName:        "frontend",
 			inSvcPort:        80,
@@ -489,7 +490,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			wantedErr: errors.New("get application app: some error"),
 		},
 		"write manifest error": {
-			inSvcType:        manifest.LoadBalancedWebServiceType,
+			inSvcType:        manifestinfo.LoadBalancedWebServiceType,
 			inAppName:        "app",
 			inSvcName:        "frontend",
 			inDockerfilePath: "frontend/Dockerfile",
@@ -510,7 +511,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			wantedErr: errors.New("write service manifest: some error"),
 		},
 		"add service to app fails": {
-			inSvcType:        manifest.LoadBalancedWebServiceType,
+			inSvcType:        manifestinfo.LoadBalancedWebServiceType,
 			inAppName:        "app",
 			inSvcName:        "frontend",
 			inSvcPort:        80,
@@ -534,7 +535,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			wantedErr: errors.New("add service frontend to application app: some error"),
 		},
 		"error saving app": {
-			inSvcType:        manifest.LoadBalancedWebServiceType,
+			inSvcType:        manifestinfo.LoadBalancedWebServiceType,
 			inAppName:        "app",
 			inSvcName:        "frontend",
 			inDockerfilePath: "frontend/Dockerfile",
@@ -556,7 +557,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			wantedErr: fmt.Errorf("saving service frontend: oops"),
 		},
 		"using existing image": {
-			inSvcType: manifest.BackendServiceType,
+			inSvcType: manifestinfo.BackendServiceType,
 			inAppName: "app",
 			inSvcName: "backend",
 			inImage:   "mockImage",
@@ -567,7 +568,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 				m.EXPECT().Rel("/backend/manifest.yml").Return("manifest.yml", nil)
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "backend").
 					Do(func(m *manifest.BackendService, _ string) {
-						require.Equal(t, *m.Workload.Type, manifest.BackendServiceType)
+						require.Equal(t, *m.Workload.Type, manifestinfo.BackendServiceType)
 						require.Equal(t, *m.ImageConfig.Image.Location, "mockImage")
 						require.Empty(t, m.ImageConfig.HealthCheck)
 					}).Return("/backend/manifest.yml", nil)
@@ -578,7 +579,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 						require.Equal(t, &config.Workload{
 							Name: "backend",
 							App:  "app",
-							Type: manifest.BackendServiceType,
+							Type: manifestinfo.BackendServiceType,
 						}, app)
 					}).
 					Return(nil)
@@ -596,7 +597,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			},
 		},
 		"no healthcheck options": {
-			inSvcType:        manifest.BackendServiceType,
+			inSvcType:        manifestinfo.BackendServiceType,
 			inAppName:        "app",
 			inSvcName:        "backend",
 			inDockerfilePath: "backend/Dockerfile",
@@ -609,7 +610,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 					m.EXPECT().Rel("/backend/manifest.yml").Return("manifest.yml", nil))
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "backend").
 					Do(func(m *manifest.BackendService, _ string) {
-						require.Equal(t, *m.Workload.Type, manifest.BackendServiceType)
+						require.Equal(t, *m.Workload.Type, manifestinfo.BackendServiceType)
 						require.Empty(t, m.ImageConfig.HealthCheck)
 					}).Return("/backend/manifest.yml", nil)
 			},
@@ -619,7 +620,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 						require.Equal(t, &config.Workload{
 							Name: "backend",
 							App:  "app",
-							Type: manifest.BackendServiceType,
+							Type: manifestinfo.BackendServiceType,
 						}, app)
 					}).
 					Return(nil)
@@ -637,7 +638,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			},
 		},
 		"default healthcheck options": {
-			inSvcType:        manifest.BackendServiceType,
+			inSvcType:        manifestinfo.BackendServiceType,
 			inAppName:        "app",
 			inSvcName:        "backend",
 			inDockerfilePath: "backend/Dockerfile",
@@ -657,7 +658,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 					m.EXPECT().Rel("/backend/manifest.yml").Return("manifest.yml", nil))
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "backend").
 					Do(func(m *manifest.BackendService, _ string) {
-						require.Equal(t, *m.Workload.Type, manifest.BackendServiceType)
+						require.Equal(t, *m.Workload.Type, manifestinfo.BackendServiceType)
 						require.Equal(t, m.ImageConfig.HealthCheck, manifest.ContainerHealthCheck{
 							Interval:    &testInterval,
 							Retries:     &testRetries,
@@ -672,7 +673,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 						require.Equal(t, &config.Workload{
 							Name: "backend",
 							App:  "app",
-							Type: manifest.BackendServiceType,
+							Type: manifestinfo.BackendServiceType,
 						}, app)
 					}).
 					Return(nil)
@@ -689,7 +690,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			},
 		},
 		"topic subscriptions enabled": {
-			inSvcType:        manifest.WorkerServiceType,
+			inSvcType:        manifestinfo.WorkerServiceType,
 			inAppName:        "app",
 			inSvcName:        "worker",
 			inDockerfilePath: "worker/Dockerfile",
@@ -708,7 +709,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 					m.EXPECT().Rel("/worker/manifest.yml").Return("manifest.yml", nil))
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "worker").
 					Do(func(m *manifest.WorkerService, _ string) {
-						require.Equal(t, *m.Workload.Type, manifest.WorkerServiceType)
+						require.Equal(t, *m.Workload.Type, manifestinfo.WorkerServiceType)
 						require.Empty(t, m.ImageConfig.HealthCheck)
 					}).Return("/worker/manifest.yml", nil)
 			},
@@ -718,7 +719,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 						require.Equal(t, &config.Workload{
 							Name: "worker",
 							App:  "app",
-							Type: manifest.WorkerServiceType,
+							Type: manifestinfo.WorkerServiceType,
 						}, app)
 					}).
 					Return(nil)
@@ -736,7 +737,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 			},
 		},
 		"topic subscriptions enabled with default fifo queue": {
-			inSvcType:        manifest.WorkerServiceType,
+			inSvcType:        manifestinfo.WorkerServiceType,
 			inAppName:        "app",
 			inSvcName:        "worker",
 			inDockerfilePath: "worker/Dockerfile",
@@ -755,7 +756,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 					m.EXPECT().Rel("/worker/manifest.yml").Return("manifest.yml", nil))
 				m.EXPECT().WriteServiceManifest(gomock.Any(), "worker").
 					Do(func(m *manifest.WorkerService, _ string) {
-						require.Equal(t, *m.Workload.Type, manifest.WorkerServiceType)
+						require.Equal(t, *m.Workload.Type, manifestinfo.WorkerServiceType)
 						require.Equal(t, *m.Subscribe.Queue.FIFO.Enable, true)
 						require.Empty(t, m.ImageConfig.HealthCheck)
 					}).Return("/worker/manifest.yml", nil)
@@ -766,7 +767,7 @@ func TestWorkloadInitializer_Service(t *testing.T) {
 						require.Equal(t, &config.Workload{
 							Name: "worker",
 							App:  "app",
-							Type: manifest.WorkerServiceType,
+							Type: manifestinfo.WorkerServiceType,
 						}, app)
 					}).
 					Return(nil)
