@@ -8,6 +8,7 @@ import (
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/stretchr/testify/require"
 	"gopkg.in/yaml.v3"
@@ -32,15 +33,17 @@ func TestNewBackendSvc(t *testing.T) {
 			wantedManifest: &BackendService{
 				Workload: Workload{
 					Name: aws.String("subscribers"),
-					Type: aws.String(BackendServiceType),
+					Type: aws.String(manifestinfo.BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
 					ImageConfig: ImageWithHealthcheckAndOptionalPort{
 						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./subscribers/Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./subscribers/Dockerfile"),
+										},
 									},
 								},
 							},
@@ -91,13 +94,15 @@ func TestNewBackendSvc(t *testing.T) {
 			wantedManifest: &BackendService{
 				Workload: Workload{
 					Name: aws.String("subscribers"),
-					Type: aws.String(BackendServiceType),
+					Type: aws.String(manifestinfo.BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
 					ImageConfig: ImageWithHealthcheckAndOptionalPort{
 						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
-								Location: aws.String("mockImage"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Location: aws.String("mockImage"),
+								},
 							},
 							Port: aws.Uint16(8080),
 						},
@@ -136,15 +141,17 @@ func TestNewBackendSvc(t *testing.T) {
 			wantedManifest: &BackendService{
 				Workload: Workload{
 					Name: aws.String("subscribers"),
-					Type: aws.String(BackendServiceType),
+					Type: aws.String(manifestinfo.BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
 					ImageConfig: ImageWithHealthcheckAndOptionalPort{
 						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./subscribers/Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./subscribers/Dockerfile"),
+										},
 									},
 								},
 							},
@@ -264,7 +271,7 @@ func TestBackendService_RequiredEnvironmentFeatures(t *testing.T) {
 			inSvc := BackendService{
 				Workload: Workload{
 					Name: aws.String("mock-svc"),
-					Type: aws.String(BackendServiceType),
+					Type: aws.String(manifestinfo.BackendServiceType),
 				},
 			}
 			tc.mft(&inSvc)
@@ -359,15 +366,17 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 	mockBackendServiceWithNoEnvironments := BackendService{
 		Workload: Workload{
 			Name: aws.String("phonetool"),
-			Type: aws.String(BackendServiceType),
+			Type: aws.String(manifestinfo.BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
 			ImageConfig: ImageWithHealthcheckAndOptionalPort{
 				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
-						Build: BuildArgsOrString{
-							BuildArgs: DockerBuildArgs{
-								Dockerfile: aws.String("./Dockerfile"),
+						ImageLocationOrBuild: ImageLocationOrBuild{
+							Build: BuildArgsOrString{
+								BuildArgs: DockerBuildArgs{
+									Dockerfile: aws.String("./Dockerfile"),
+								},
 							},
 						},
 					},
@@ -442,8 +451,10 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			},
 			Sidecars: map[string]*SidecarConfig{
 				"xray": {
-					Port:  aws.String("2000/udp"),
-					Image: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+					Port: aws.String("2000/udp"),
+					Image: Union[*string, ImageLocationOrBuild]{
+						Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+					},
 				},
 			},
 			Logging: Logging{
@@ -496,15 +507,17 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 	mockBackendServiceWithImageOverrideBuildByLocation := BackendService{
 		Workload: Workload{
 			Name: aws.String("phonetool"),
-			Type: aws.String(BackendServiceType),
+			Type: aws.String(manifestinfo.BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
 			ImageConfig: ImageWithHealthcheckAndOptionalPort{
 				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
-						Build: BuildArgsOrString{
-							BuildArgs: DockerBuildArgs{
-								Dockerfile: aws.String("./Dockerfile"),
+						ImageLocationOrBuild: ImageLocationOrBuild{
+							Build: BuildArgsOrString{
+								BuildArgs: DockerBuildArgs{
+									Dockerfile: aws.String("./Dockerfile"),
+								},
 							},
 						},
 					},
@@ -516,7 +529,9 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 				ImageConfig: ImageWithHealthcheckAndOptionalPort{
 					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
-							Location: aws.String("env-override location"),
+							ImageLocationOrBuild: ImageLocationOrBuild{
+								Location: aws.String("env-override location"),
+							},
 						},
 					},
 				},
@@ -526,13 +541,15 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 	mockBackendServiceWithImageOverrideLocationByLocation := BackendService{
 		Workload: Workload{
 			Name: aws.String("phonetool"),
-			Type: aws.String(BackendServiceType),
+			Type: aws.String(manifestinfo.BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
 			ImageConfig: ImageWithHealthcheckAndOptionalPort{
 				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
-						Location: aws.String("original location"),
+						ImageLocationOrBuild: ImageLocationOrBuild{
+							Location: aws.String("original location"),
+						},
 					},
 				},
 			},
@@ -542,7 +559,9 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 				ImageConfig: ImageWithHealthcheckAndOptionalPort{
 					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
-							Location: aws.String("env-override location"),
+							ImageLocationOrBuild: ImageLocationOrBuild{
+								Location: aws.String("env-override location"),
+							},
 						},
 					},
 				},
@@ -552,16 +571,18 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 	mockBackendServiceWithImageOverrideBuildByBuild := BackendService{
 		Workload: Workload{
 			Name: aws.String("phonetool"),
-			Type: aws.String(BackendServiceType),
+			Type: aws.String(manifestinfo.BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
 			ImageConfig: ImageWithHealthcheckAndOptionalPort{
 				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
-						Build: BuildArgsOrString{
-							BuildArgs: DockerBuildArgs{
-								Dockerfile: aws.String("original dockerfile"),
-								Context:    aws.String("original context"),
+						ImageLocationOrBuild: ImageLocationOrBuild{
+							Build: BuildArgsOrString{
+								BuildArgs: DockerBuildArgs{
+									Dockerfile: aws.String("original dockerfile"),
+									Context:    aws.String("original context"),
+								},
 							},
 						},
 					},
@@ -573,8 +594,10 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 				ImageConfig: ImageWithHealthcheckAndOptionalPort{
 					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
-							Build: BuildArgsOrString{
-								BuildString: aws.String("env overridden dockerfile"),
+							ImageLocationOrBuild: ImageLocationOrBuild{
+								Build: BuildArgsOrString{
+									BuildString: aws.String("env overridden dockerfile"),
+								},
 							},
 						},
 					},
@@ -585,13 +608,15 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 	mockBackendServiceWithImageOverrideLocationByBuild := BackendService{
 		Workload: Workload{
 			Name: aws.String("phonetool"),
-			Type: aws.String(BackendServiceType),
+			Type: aws.String(manifestinfo.BackendServiceType),
 		},
 		BackendServiceConfig: BackendServiceConfig{
 			ImageConfig: ImageWithHealthcheckAndOptionalPort{
 				ImageWithOptionalPort: ImageWithOptionalPort{
 					Image: Image{
-						Location: aws.String("original location"),
+						ImageLocationOrBuild: ImageLocationOrBuild{
+							Location: aws.String("original location"),
+						},
 					},
 				},
 			},
@@ -601,8 +626,10 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 				ImageConfig: ImageWithHealthcheckAndOptionalPort{
 					ImageWithOptionalPort: ImageWithOptionalPort{
 						Image: Image{
-							Build: BuildArgsOrString{
-								BuildString: aws.String("env overridden dockerfile"),
+							ImageLocationOrBuild: ImageLocationOrBuild{
+								Build: BuildArgsOrString{
+									BuildString: aws.String("env overridden dockerfile"),
+								},
 							},
 						},
 					},
@@ -680,8 +707,10 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000/udp"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000/udp"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
@@ -703,13 +732,15 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			wanted: &BackendService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(BackendServiceType),
+					Type: aws.String(manifestinfo.BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
 					ImageConfig: ImageWithHealthcheckAndOptionalPort{
 						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
-								Location: aws.String("env-override location"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Location: aws.String("env-override location"),
+								},
 							},
 						},
 					},
@@ -724,13 +755,15 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			wanted: &BackendService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(BackendServiceType),
+					Type: aws.String(manifestinfo.BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
 					ImageConfig: ImageWithHealthcheckAndOptionalPort{
 						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
-								Location: aws.String("env-override location"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Location: aws.String("env-override location"),
+								},
 							},
 						},
 					},
@@ -744,14 +777,16 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			wanted: &BackendService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(BackendServiceType),
+					Type: aws.String(manifestinfo.BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
 					ImageConfig: ImageWithHealthcheckAndOptionalPort{
 						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildString: aws.String("env overridden dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildString: aws.String("env overridden dockerfile"),
+									},
 								},
 							},
 						},
@@ -766,14 +801,16 @@ func TestBackendSvc_ApplyEnv(t *testing.T) {
 			wanted: &BackendService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(BackendServiceType),
+					Type: aws.String(manifestinfo.BackendServiceType),
 				},
 				BackendServiceConfig: BackendServiceConfig{
 					ImageConfig: ImageWithHealthcheckAndOptionalPort{
 						ImageWithOptionalPort: ImageWithOptionalPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildString: aws.String("env overridden dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildString: aws.String("env overridden dockerfile"),
+									},
 								},
 							},
 						},
@@ -963,7 +1000,7 @@ func TestBackendSvc_ApplyEnv_CountOverrides(t *testing.T) {
 func TestBackendService_ExposedPorts(t *testing.T) {
 	testCases := map[string]struct {
 		mft                *BackendService
-		wantedExposedPorts []ExposedPort
+		wantedExposedPorts map[string][]ExposedPort
 	}{
 		"expose primary container port through target_port": {
 			mft: &BackendService{
@@ -977,23 +1014,29 @@ func TestBackendService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          81,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          81,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1014,28 +1057,34 @@ func TestBackendService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          81,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1056,28 +1105,34 @@ func TestBackendService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          81,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1098,23 +1153,31 @@ func TestBackendService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							//Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Advanced: ImageLocationOrBuild{
+									Location: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+								},
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          81,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1126,7 +1189,7 @@ func TestBackendService_ExposedPorts(t *testing.T) {
 
 			// THEN
 			require.NoError(t, err)
-			require.Equal(t, tc.wantedExposedPorts, actual)
+			require.Equal(t, tc.wantedExposedPorts, actual.PortsForContainer)
 		})
 	}
 }
