@@ -9,6 +9,7 @@ import (
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/stretchr/testify/require"
 	"gopkg.in/yaml.v3"
@@ -39,9 +40,11 @@ func TestNewHTTPLoadBalancedWebService(t *testing.T) {
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: stringP("./Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: stringP("./Dockerfile"),
+										},
 									},
 								},
 							},
@@ -102,15 +105,17 @@ func TestNewHTTPLoadBalancedWebService(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: stringP("subscribers"),
-					Type: stringP(LoadBalancedWebServiceType),
+					Type: stringP(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./subscribers/Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./subscribers/Dockerfile"),
+										},
 									},
 								},
 							},
@@ -251,15 +256,17 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./Dockerfile"),
+										},
 									},
 								},
 							},
@@ -317,15 +324,17 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./Dockerfile"),
+										},
 									},
 								},
 							},
@@ -383,15 +392,17 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./Dockerfile"),
+										},
 									},
 								},
 							},
@@ -472,8 +483,10 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
@@ -498,9 +511,11 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						ImageConfig: ImageWithPortAndHealthcheck{
 							ImageWithPort: ImageWithPort{
 								Image: Image{
-									Build: BuildArgsOrString{
-										BuildArgs: DockerBuildArgs{
-											Dockerfile: aws.String("./RealDockerfile"),
+									ImageLocationOrBuild: ImageLocationOrBuild{
+										Build: BuildArgsOrString{
+											BuildArgs: DockerBuildArgs{
+												Dockerfile: aws.String("./RealDockerfile"),
+											},
 										},
 									},
 								},
@@ -597,15 +612,17 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./RealDockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./RealDockerfile"),
+										},
 									},
 								},
 							},
@@ -683,8 +700,10 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000/udp"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000/udp"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 							MountPoints: []SidecarMountPoint{
 								{
@@ -1121,15 +1140,17 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./Dockerfile"),
+										},
 									},
 								},
 							},
@@ -1141,7 +1162,9 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						ImageConfig: ImageWithPortAndHealthcheck{
 							ImageWithPort: ImageWithPort{
 								Image: Image{
-									Location: aws.String("env-override location"),
+									ImageLocationOrBuild: ImageLocationOrBuild{
+										Location: aws.String("env-override location"),
+									},
 								},
 							},
 						},
@@ -1153,13 +1176,15 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Location: aws.String("env-override location"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Location: aws.String("env-override location"),
+								},
 							},
 						},
 					},
@@ -1170,13 +1195,15 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Location: aws.String("default location"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Location: aws.String("default location"),
+								},
 							},
 						},
 					},
@@ -1186,7 +1213,9 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						ImageConfig: ImageWithPortAndHealthcheck{
 							ImageWithPort: ImageWithPort{
 								Image: Image{
-									Location: aws.String("env-override location"),
+									ImageLocationOrBuild: ImageLocationOrBuild{
+										Location: aws.String("env-override location"),
+									},
 								},
 							},
 						},
@@ -1198,13 +1227,15 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Location: aws.String("env-override location"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Location: aws.String("env-override location"),
+								},
 							},
 						},
 					},
@@ -1215,15 +1246,17 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildArgs: DockerBuildArgs{
-										Dockerfile: aws.String("./Dockerfile"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildArgs: DockerBuildArgs{
+											Dockerfile: aws.String("./Dockerfile"),
+										},
 									},
 								},
 							},
@@ -1235,8 +1268,10 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						ImageConfig: ImageWithPortAndHealthcheck{
 							ImageWithPort: ImageWithPort{
 								Image: Image{
-									Build: BuildArgsOrString{
-										BuildString: aws.String("overridden build string"),
+									ImageLocationOrBuild: ImageLocationOrBuild{
+										Build: BuildArgsOrString{
+											BuildString: aws.String("overridden build string"),
+										},
 									},
 								},
 							},
@@ -1249,14 +1284,16 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildString: aws.String("overridden build string"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildString: aws.String("overridden build string"),
+									},
 								},
 							},
 						},
@@ -1268,13 +1305,15 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Location: aws.String("default location"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Location: aws.String("default location"),
+								},
 							},
 						},
 					},
@@ -1284,8 +1323,10 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 						ImageConfig: ImageWithPortAndHealthcheck{
 							ImageWithPort: ImageWithPort{
 								Image: Image{
-									Build: BuildArgsOrString{
-										BuildString: aws.String("overridden build string"),
+									ImageLocationOrBuild: ImageLocationOrBuild{
+										Build: BuildArgsOrString{
+											BuildString: aws.String("overridden build string"),
+										},
 									},
 								},
 							},
@@ -1298,14 +1339,16 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageConfig: ImageWithPortAndHealthcheck{
 						ImageWithPort: ImageWithPort{
 							Image: Image{
-								Build: BuildArgsOrString{
-									BuildString: aws.String("overridden build string"),
+								ImageLocationOrBuild: ImageLocationOrBuild{
+									Build: BuildArgsOrString{
+										BuildString: aws.String("overridden build string"),
+									},
 								},
 							},
 						},
@@ -1317,7 +1360,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageOverride: ImageOverride{
@@ -1341,7 +1384,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					ImageOverride: ImageOverride{
@@ -1356,7 +1399,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					RoutingRule: RoutingRuleConfigOrBool{
@@ -1383,7 +1426,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					RoutingRule: RoutingRuleConfigOrBool{
@@ -1401,7 +1444,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					RoutingRule: RoutingRuleConfigOrBool{
@@ -1430,7 +1473,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					RoutingRule: RoutingRuleConfigOrBool{
@@ -1448,7 +1491,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			in: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					RoutingRule: RoutingRuleConfigOrBool{
@@ -1478,7 +1521,7 @@ func TestLoadBalancedWebService_ApplyEnv(t *testing.T) {
 			wanted: &LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("phonetool"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
 					RoutingRule: RoutingRuleConfigOrBool{
@@ -1573,25 +1616,31 @@ func TestLoadBalancedWebService_BuildRequired(t *testing.T) {
 	}{
 		"error if both build and location are set or not set": {
 			image: Image{
-				Build: BuildArgsOrString{
-					BuildString: aws.String("mockBuildString"),
+				ImageLocationOrBuild: ImageLocationOrBuild{
+					Build: BuildArgsOrString{
+						BuildString: aws.String("mockBuildString"),
+					},
+					Location: aws.String("mockLocation"),
 				},
-				Location: aws.String("mockLocation"),
 			},
 			wantErr: fmt.Errorf(`either "image.build" or "image.location" needs to be specified in the manifest`),
 		},
 		"return true if location is not set": {
 			image: Image{
-				Build: BuildArgsOrString{
-					BuildString: aws.String("mockBuildString"),
+				ImageLocationOrBuild: ImageLocationOrBuild{
+					Build: BuildArgsOrString{
+						BuildString: aws.String("mockBuildString"),
+					},
 				},
 			},
 			want: true,
 		},
 		"return false if location is set": {
 			image: Image{
-				Build:    BuildArgsOrString{},
-				Location: aws.String("mockLocation"),
+				ImageLocationOrBuild: ImageLocationOrBuild{
+					Build:    BuildArgsOrString{},
+					Location: aws.String("mockLocation"),
+				},
 			},
 			want: false,
 		},
@@ -1744,7 +1793,7 @@ func TestLoadBalancedWebService_RequiredEnvironmentFeatures(t *testing.T) {
 			inSvc := LoadBalancedWebService{
 				Workload: Workload{
 					Name: aws.String("mock-svc"),
-					Type: aws.String(LoadBalancedWebServiceType),
+					Type: aws.String(manifestinfo.LoadBalancedWebServiceType),
 				},
 			}
 			tc.mft(&inSvc)
@@ -1757,7 +1806,7 @@ func TestLoadBalancedWebService_RequiredEnvironmentFeatures(t *testing.T) {
 func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 	testCases := map[string]struct {
 		mft                *LoadBalancedWebService
-		wantedExposedPorts []ExposedPort
+		wantedExposedPorts map[string][]ExposedPort
 	}{
 		"expose new sidecar container port through alb target_port and target_container": {
 			mft: &LoadBalancedWebService{
@@ -1779,28 +1828,34 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "xray",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          81,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1823,28 +1878,34 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          81,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1868,28 +1929,34 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          81,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1913,22 +1980,28 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          81,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1951,23 +2024,29 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("81"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("81"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          81,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -1990,23 +2069,29 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("81"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("81"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          81,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -2033,28 +2118,34 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          81,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -2079,33 +2170,39 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          81,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          82,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          81,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          82,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -2125,28 +2222,34 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("2000"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("2000"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          80,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          82,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          82,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          2000,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          2000,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -2172,23 +2275,29 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("80"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("80"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"xray": {
+					{
+						Port:          80,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          8080,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
+				"frontend": {
+					{
+						Port:          8080,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -2215,33 +2324,39 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 					},
 					Sidecars: map[string]*SidecarConfig{
 						"xray": {
-							Port:       aws.String("80"),
-							Image:      aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							Port: aws.String("80"),
+							Image: Union[*string, ImageLocationOrBuild]{
+								Basic: aws.String("123456789012.dkr.ecr.us-east-2.amazonaws.com/xray-daemon"),
+							},
 							CredsParam: aws.String("some arn"),
 						},
 					},
 				},
 			},
-			wantedExposedPorts: []ExposedPort{
-				{
-					Port:          80,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+			wantedExposedPorts: map[string][]ExposedPort{
+				"frontend": {
+					{
+						Port:          8080,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          8081,
+						ContainerName: "frontend",
+						Protocol:      "tcp",
+					},
 				},
-				{
-					Port:          8080,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          8081,
-					ContainerName: "frontend",
-					Protocol:      "tcp",
-				},
-				{
-					Port:          8082,
-					ContainerName: "xray",
-					Protocol:      "tcp",
+				"xray": {
+					{
+						Port:          80,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
+					{
+						Port:          8082,
+						ContainerName: "xray",
+						Protocol:      "tcp",
+					},
 				},
 			},
 		},
@@ -2253,7 +2368,7 @@ func TestLoadBalancedWebService_ExposedPorts(t *testing.T) {
 
 			// THEN
 			require.NoError(t, err)
-			require.Equal(t, tc.wantedExposedPorts, actual)
+			require.Equal(t, tc.wantedExposedPorts, actual.PortsForContainer)
 		})
 	}
 }
