@@ -5,6 +5,7 @@ package manifest
 
 import (
 	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/imdario/mergo"
 )
@@ -32,6 +33,7 @@ type RequestDrivenWebServiceConfig struct {
 	InstanceConfig                    AppRunnerInstanceConfig              `yaml:",inline"`
 	ImageConfig                       ImageWithPort                        `yaml:"image"`
 	Variables                         map[string]Variable                  `yaml:"variables"`
+	Secrets                           map[string]Secret                    `yaml:"secrets"`
 	StartCommand                      *string                              `yaml:"command"`
 	Tags                              map[string]string                    `yaml:"tags"`
 	PublishConfig                     PublishConfig                        `yaml:"publish"`
@@ -190,7 +192,7 @@ func (s *RequestDrivenWebService) requiredEnvironmentFeatures() []string {
 func newDefaultRequestDrivenWebService() *RequestDrivenWebService {
 	return &RequestDrivenWebService{
 		Workload: Workload{
-			Type: aws.String(RequestDrivenWebServiceType),
+			Type: aws.String(manifestinfo.RequestDrivenWebServiceType),
 		},
 		RequestDrivenWebServiceConfig: RequestDrivenWebServiceConfig{
 			ImageConfig: ImageWithPort{},
