@@ -12,37 +12,25 @@ import (
 	"strings"
 	"time"
 
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
+	"github.com/aws/copilot-cli/internal/pkg/template"
+
 	"github.com/aws/aws-sdk-go/aws"
 	"gopkg.in/yaml.v3"
 )
 
-const (
-	// LoadBalancedWebServiceType is a web service with a load balancer and Fargate as compute.
-	LoadBalancedWebServiceType = "Load Balanced Web Service"
-	// RequestDrivenWebServiceType is a Request-Driven Web Service managed by AppRunner
-	RequestDrivenWebServiceType = "Request-Driven Web Service"
-	// BackendServiceType is a service that cannot be accessed from the internet but can be reached from other services.
-	BackendServiceType = "Backend Service"
-	// WorkerServiceType is a worker service that manages the consumption of messages.
-	WorkerServiceType = "Worker Service"
-)
-
-// ServiceTypes returns the list of supported service manifest types.
-func ServiceTypes() []string {
-	return []string{
-		RequestDrivenWebServiceType,
-		LoadBalancedWebServiceType,
-		BackendServiceType,
-		WorkerServiceType,
-	}
-}
-
 // Range contains either a Range or a range configuration for Autoscaling ranges.
 type Range struct {
 	Value       *IntRangeBand // Mutually exclusive with RangeConfig
 	RangeConfig RangeConfig
 }
 
+// ExposedPortsIndex holds exposed ports configuration.
+type ExposedPortsIndex struct {
+	PortsForContainer map[string][]ExposedPort // holds exposed ports list for all the containers
+	ContainerForPort  map[uint16]string        // holds port to container mapping
+}
+
 // IsEmpty returns whether Range is empty.
 func (r *Range) IsEmpty() bool {
 	return r.Value == nil && r.RangeConfig.IsEmpty()
@@ -262,11 +250,11 @@ func (a *AdvancedCount) hasAutoscaling() bool {
 
 func (a *AdvancedCount) validScalingFields() []string {
 	switch a.workloadType {
-	case LoadBalancedWebServiceType:
+	case manifestinfo.LoadBalancedWebServiceType:
 		return []string{"cpu_percentage", "memory_percentage", "requests", "response_time"}
-	case BackendServiceType:
+	case manifestinfo.BackendServiceType:
 		return []string{"cpu_percentage", "memory_percentage", "requests", "response_time"}
-	case WorkerServiceType:
+	case manifestinfo.WorkerServiceType:
 		return []string{"cpu_percentage", "memory_percentage", "queue_delay"}
 	default:
 		return nil
@@ -275,11 +263,11 @@ func (a *AdvancedCount) validScalingFields() []string {
 
 func (a *AdvancedCount) hasScalingFieldsSet() bool {
 	switch a.workloadType {
-	case LoadBalancedWebServiceType:
+	case manifestinfo.LoadBalancedWebServiceType:
 		return !a.CPU.IsEmpty() || !a.Memory.IsEmpty() || !a.Requests.IsEmpty() || !a.ResponseTime.IsEmpty()
-	case BackendServiceType:
+	case manifestinfo.BackendServiceType:
 		return !a.CPU.IsEmpty() || !a.Memory.IsEmpty() || !a.Requests.IsEmpty() || !a.ResponseTime.IsEmpty()
-	case WorkerServiceType:
+	case manifestinfo.WorkerServiceType:
 		return !a.CPU.IsEmpty() || !a.Memory.IsEmpty() || !a.QueueScaling.IsEmpty()
 	default:
 		return !a.CPU.IsEmpty() || !a.Memory.IsEmpty() || !a.Requests.IsEmpty() || !a.ResponseTime.IsEmpty() || !a.QueueScaling.IsEmpty()
@@ -290,15 +278,15 @@ func (a *AdvancedCount) getInvalidFieldsSet() []string {
 	var invalidFields []string
 
 	switch a.workloadType {
-	case LoadBalancedWebServiceType:
+	case manifestinfo.LoadBalancedWebServiceType:
 		if !a.QueueScaling.IsEmpty() {
 			invalidFields = append(invalidFields, "queue_delay")
 		}
-	case BackendServiceType:
+	case manifestinfo.BackendServiceType:
 		if !a.QueueScaling.IsEmpty() {
 			invalidFields = append(invalidFields, "queue_delay")
 		}
-	case WorkerServiceType:
+	case manifestinfo.WorkerServiceType:
 		if !a.Requests.IsEmpty() {
 			invalidFields = append(invalidFields, "requests")
 		}
@@ -341,17 +329,6 @@ func (qs *QueueScaling) AcceptableBacklogPerTask() (int, error) {
 	return int(v), nil
 }
 
-// IsTypeAService returns if manifest type is service.
-func IsTypeAService(t string) bool {
-	for _, serviceType := range ServiceTypes() {
-		if t == serviceType {
-			return true
-		}
-	}
-
-	return false
-}
-
 // HTTPHealthCheckArgs holds the configuration to determine if the load balanced web service is healthy.
 // These options are specifiable under the "healthcheck" field.
 // See https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-targetgroup.html.
@@ -505,13 +482,10 @@ func (cfg NetworkLoadBalancerConfiguration) exposedPorts(exposedPorts []ExposedP
 	if cfg.IsEmpty() {
 		return nil, nil
 	}
-	nlbPort, protocol, err := ParsePortMapping(cfg.Port)
+	nlbPort, _, err := ParsePortMapping(cfg.Port)
 	if err != nil {
 		return nil, err
 	}
-	if protocol == nil {
-		protocol = aws.String("tcp")
-	}
 
 	port, err := strconv.ParseUint(aws.StringValue(nlbPort), 10, 16)
 	if err != nil {
@@ -533,7 +507,7 @@ func (cfg NetworkLoadBalancerConfiguration) exposedPorts(exposedPorts []ExposedP
 	return []ExposedPort{
 		{
 			Port:          targetPort,
-			Protocol:      aws.StringValue(protocol),
+			Protocol:      "tcp",
 			ContainerName: targetContainer,
 		},
 	}, nil
@@ -543,12 +517,13 @@ func (sidecar SidecarConfig) exposedPorts(sidecarName string) ([]ExposedPort, er
 	if sidecar.Port == nil {
 		return nil, nil
 	}
-	sidecarPort, protocol, err := ParsePortMapping(sidecar.Port)
+	sidecarPort, protocolPtr, err := ParsePortMapping(sidecar.Port)
 	if err != nil {
 		return nil, err
 	}
-	if protocol == nil {
-		protocol = aws.String("tcp")
+	protocol := aws.StringValue(protocolPtr)
+	if protocolPtr == nil {
+		protocol = "tcp"
 	}
 	port, err := strconv.ParseUint(aws.StringValue(sidecarPort), 10, 16)
 	if err != nil {
@@ -557,7 +532,7 @@ func (sidecar SidecarConfig) exposedPorts(sidecarName string) ([]ExposedPort, er
 	return []ExposedPort{
 		{
 			Port:          uint16(port),
-			Protocol:      aws.StringValue(protocol),
+			Protocol:      strings.ToLower(protocol),
 			ContainerName: sidecarName,
 		},
 	}, nil
@@ -570,3 +545,151 @@ func sortExposedPorts(exposedPorts []ExposedPort) []ExposedPort {
 	})
 	return exposedPorts
 }
+
+// HTTPLoadBalancerTarget returns target container and target port for the ALB configuration.
+// This method should be called only when ALB config is not empty.
+func (s *LoadBalancedWebService) HTTPLoadBalancerTarget() (targetContainer string, targetPort string, err error) {
+	exposedPorts, err := s.ExposedPorts()
+	if err != nil {
+		return "", "", err
+	}
+	// Route load balancer traffic to main container by default.
+	targetContainer = aws.StringValue(s.Name)
+	targetPort = s.MainContainerPort()
+
+	rrTargetContainer := s.RoutingRule.TargetContainer
+	rrTargetPort := s.RoutingRule.TargetPort
+	if rrTargetContainer == nil && rrTargetPort == nil { // both targetPort and targetContainer are nil.
+		return
+	}
+
+	if rrTargetPort == nil { // when target_port is nil
+		if rrTargetContainer != s.Name {
+			targetContainer = aws.StringValue(rrTargetContainer)
+			targetPort = aws.StringValue(s.Sidecars[aws.StringValue(rrTargetContainer)].Port)
+		}
+		return
+	}
+
+	if rrTargetContainer == nil { // when target_container is nil
+		container, port := httpLoadBalancerTarget(exposedPorts, rrTargetPort)
+		targetPort = aws.StringValue(port)
+		if container != nil {
+			targetContainer = aws.StringValue(container)
+		}
+		return
+	}
+
+	// when both target_port and target_container are not nil
+	targetContainer = aws.StringValue(rrTargetContainer)
+	targetPort = template.StrconvUint16(aws.Uint16Value(rrTargetPort))
+
+	return
+}
+
+// HTTPLoadBalancerTarget returns target container and target port for the ALB configuration.
+// This method should be called only when ALB config is not empty.
+func (s *BackendService) HTTPLoadBalancerTarget() (targetContainer string, targetPort string, err error) {
+	exposedPorts, err := s.ExposedPorts()
+	if err != nil {
+		return "", "", err
+	}
+
+	// Route load balancer traffic to main container by default.
+	targetContainer = aws.StringValue(s.Name)
+	targetPort = s.MainContainerPort()
+
+	rrTargetContainer := s.RoutingRule.TargetContainer
+	rrTargetPort := s.RoutingRule.TargetPort
+	if rrTargetContainer == nil && rrTargetPort == nil { // both targetPort and targetContainer are nil.
+		return
+	}
+
+	if rrTargetPort == nil { // when target_port is nil
+		if rrTargetContainer != s.Name {
+			targetContainer = aws.StringValue(rrTargetContainer)
+			targetPort = aws.StringValue(s.Sidecars[aws.StringValue(rrTargetContainer)].Port)
+		}
+		return
+	}
+
+	if rrTargetContainer == nil { // when target_container is nil
+		container, port := httpLoadBalancerTarget(exposedPorts, rrTargetPort)
+		targetPort = aws.StringValue(port)
+		if container != nil {
+			targetContainer = aws.StringValue(container)
+		}
+		return
+	}
+
+	// when both target_port and target_container are not nil
+	targetContainer = aws.StringValue(rrTargetContainer)
+	targetPort = template.StrconvUint16(aws.Uint16Value(rrTargetPort))
+	return
+}
+
+func httpLoadBalancerTarget(exposedPorts ExposedPortsIndex, rrTargetPort *uint16) (targetContainer *string, targetPort *string) {
+	// Route load balancer traffic to the target_port if mentioned.
+	targetPort = aws.String(template.StrconvUint16(aws.Uint16Value(rrTargetPort)))
+	// It shouldn’t be possible that container is empty for the given port as exposed port assigns container to all the ports, this is just for the extra safety.
+	if exposedPorts.ContainerForPort[aws.Uint16Value(rrTargetPort)] != "" {
+		targetContainer = aws.String(exposedPorts.ContainerForPort[aws.Uint16Value(rrTargetPort)])
+	}
+	return
+}
+
+// MainContainerPort returns the main container port.
+func (s *LoadBalancedWebService) MainContainerPort() string {
+	return strconv.FormatUint(uint64(aws.Uint16Value(s.ImageConfig.Port)), 10)
+}
+
+// MainContainerPort returns the main container port if given.
+func (s *BackendService) MainContainerPort() string {
+	port := template.NoExposedContainerPort
+	if s.BackendServiceConfig.ImageConfig.Port != nil {
+		port = strconv.FormatUint(uint64(aws.Uint16Value(s.BackendServiceConfig.ImageConfig.Port)), 10)
+	}
+	return port
+}
+
+func prepareParsedExposedPortsMap(exposedPorts []ExposedPort) (map[string][]ExposedPort, map[uint16]string) {
+	parsedContainerMap := make(map[string][]ExposedPort)
+	parsedExposedPortMap := make(map[uint16]string)
+	for _, exposedPort := range exposedPorts {
+		parsedContainerMap[exposedPort.ContainerName] = append(parsedContainerMap[exposedPort.ContainerName], exposedPort)
+		parsedExposedPortMap[exposedPort.Port] = exposedPort.ContainerName
+	}
+	return parsedContainerMap, parsedExposedPortMap
+}
+
+// NetworkLoadBalancerTarget returns target container and target port for the NLB configuration.
+// This method should be called only when NLB config is not empty.
+func (s *LoadBalancedWebService) NetworkLoadBalancerTarget() (targetContainer string, targetPort string, err error) {
+	// Configure target container and port.
+	targetContainer = aws.StringValue(s.Name)
+	if s.NLBConfig.TargetContainer != nil {
+		targetContainer = aws.StringValue(s.NLBConfig.TargetContainer)
+	}
+
+	// Parse listener port and protocol.
+	port, _, err := ParsePortMapping(s.NLBConfig.Port)
+	if err != nil {
+		return "", "", err
+	}
+	// By default, the target port is the same as listener port.
+	targetPort = aws.StringValue(port)
+	if targetContainer != aws.StringValue(s.Name) {
+		// If the target container is a sidecar container, the target port is the exposed sidecar port.
+		sideCarPort := s.Sidecars[targetContainer].Port // We validated that a sidecar container exposes a port if it is a target container.
+		port, _, err := ParsePortMapping(sideCarPort)
+		if err != nil {
+			return "", "", err
+		}
+		targetPort = aws.StringValue(port)
+	}
+	// Finally, if a target port is explicitly specified, use that value.
+	if s.NLBConfig.TargetPort != nil {
+		targetPort = strconv.Itoa(aws.IntValue(s.NLBConfig.TargetPort))
+	}
+	return
+}
