@@ -15,6 +15,7 @@ import (
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/copilot-cli/internal/pkg/graph"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/dustin/go-humanize/english"
 )
 
@@ -35,7 +36,7 @@ const (
 const (
 	// Protocols.
 	TCP = "TCP"
-	tls = "TLS"
+	TLS = "TLS"
 	udp = "UDP"
 
 	// Tracing vendors.
@@ -52,7 +53,7 @@ var (
 
 	essentialContainerDependsOnValidStatuses = []string{dependsOnStart, dependsOnHealthy}
 	dependsOnValidStatuses                   = []string{dependsOnStart, dependsOnComplete, dependsOnSuccess, dependsOnHealthy}
-	nlbValidProtocols                        = []string{TCP, tls}
+	nlbValidProtocols                        = []string{TCP, TLS}
 	validContainerProtocols                  = []string{TCP, udp}
 	TracingValidVendors                      = []string{awsXRAY}
 	ecsRollingUpdateStrategies               = []string{ECSDefaultRollingUpdateStrategy, ECSRecreateRollingUpdateStrategy}
@@ -107,19 +108,40 @@ func (l LoadBalancedWebService) validate() error {
 		mainContainerPort: l.ImageConfig.Port,
 		sidecarConfig:     l.Sidecars,
 		alb:               &l.RoutingRule.RoutingRuleConfiguration,
+		nlb:               &l.NLBConfig,
 	}); err != nil {
 		return fmt.Errorf("validate unique exposed ports: %w", err)
 	}
 	return nil
 }
 
-func (d DeploymentConfiguration) validate() error {
+func (d DeploymentConfig) validate() error {
 	if d.isEmpty() {
 		return nil
 	}
 	if err := d.RollbackAlarms.validate(); err != nil {
 		return fmt.Errorf(`validate "rollback_alarms": %w`, err)
 	}
+	if err := d.DeploymentControllerConfig.validate(); err != nil {
+		return fmt.Errorf(`validate "rolling": %w`, err)
+	}
+	return nil
+}
+
+func (w WorkerDeploymentConfig) validate() error {
+	if w.isEmpty() {
+		return nil
+	}
+	if err := w.WorkerRollbackAlarms.validate(); err != nil {
+		return fmt.Errorf(`validate "rollback_alarms": %w`, err)
+	}
+	if err := w.DeploymentControllerConfig.validate(); err != nil {
+		return fmt.Errorf(`validate "deployment controller strategy": %w`, err)
+	}
+	return nil
+}
+
+func (d DeploymentControllerConfig) validate() error {
 	if d.Rolling != nil {
 		for _, validStrategy := range ecsRollingUpdateStrategies {
 			if strings.EqualFold(aws.StringValue(d.Rolling), validStrategy) {
@@ -137,6 +159,10 @@ func (a AlarmArgs) validate() error {
 	return nil
 }
 
+func (w WorkerAlarmArgs) validate() error {
+	return nil
+}
+
 // validate returns nil if LoadBalancedWebServiceConfig is configured correctly.
 func (l LoadBalancedWebServiceConfig) validate() error {
 	var err error
@@ -336,7 +362,7 @@ func (r RequestDrivenWebServiceConfig) validate() error {
 	if r.Network.VPC.Placement.PlacementString != nil &&
 		*r.Network.VPC.Placement.PlacementString != PrivateSubnetPlacement {
 		return fmt.Errorf(`placement %q is not supported for %s`,
-			*r.Network.VPC.Placement.PlacementString, RequestDrivenWebServiceType)
+			*r.Network.VPC.Placement.PlacementString, manifestinfo.RequestDrivenWebServiceType)
 	}
 	if err = r.Observability.validate(); err != nil {
 		return fmt.Errorf(`validate "observability": %w`, err)
@@ -347,9 +373,6 @@ func (r RequestDrivenWebServiceConfig) validate() error {
 // validate returns nil if WorkerService is configured correctly.
 func (w WorkerService) validate() error {
 	var err error
-	if err = w.DeployConfig.validate(); err != nil {
-		return fmt.Errorf(`validate "deployment": %w`, err)
-	}
 	if err = w.WorkerServiceConfig.validate(); err != nil {
 		return err
 	}
@@ -375,6 +398,9 @@ func (w WorkerService) validate() error {
 // validate returns nil if WorkerServiceConfig is configured correctly.
 func (w WorkerServiceConfig) validate() error {
 	var err error
+	if err = w.DeployConfig.validate(); err != nil {
+		return fmt.Errorf(`validate "deployment": %w`, err)
+	}
 	if err = w.ImageConfig.validate(); err != nil {
 		return fmt.Errorf(`validate "image": %w`, err)
 	}
@@ -509,6 +535,27 @@ func (s ScheduledJobConfig) validate() error {
 	return nil
 }
 
+// validate returns nil if StaticSite is configured correctly.
+func (s StaticSite) validate() error {
+	if err := s.StaticSiteConfig.validate(); err != nil {
+		return err
+	}
+	return s.Workload.validate()
+}
+
+func (s StaticSiteConfig) validate() error {
+	for idx, fileupload := range s.FileUploads {
+		if err := fileupload.validate(); err != nil {
+			return fmt.Errorf(`validate "files[%d]": %w`, idx, err)
+		}
+	}
+	return nil
+}
+
+func (f FileUpload) validate() error {
+	return nil
+}
+
 // validate returns nil if the pipeline manifest is configured correctly.
 func (p Pipeline) Validate() error {
 	if len(p.Name) > 100 {
@@ -608,8 +655,8 @@ func (i ImageWithPort) validate() error {
 // validate returns nil if Image is configured correctly.
 func (i Image) validate() error {
 	var err error
-	if err = i.Build.validate(); err != nil {
-		return fmt.Errorf(`validate "build": %w`, err)
+	if err := i.ImageLocationOrBuild.validate(); err != nil {
+		return err
 	}
 	if i.Build.isEmpty() == (i.Location == nil) {
 		return &errFieldMutualExclusive{
@@ -1302,6 +1349,9 @@ func (s SidecarConfig) validate() error {
 	if err := s.DependsOn.validate(); err != nil {
 		return fmt.Errorf(`validate "depends_on": %w`, err)
 	}
+	if err := s.Image.Advanced.validate(); err != nil {
+		return fmt.Errorf(`validate "build": %w`, err)
+	}
 	return s.ImageOverride.validate()
 }
 
@@ -2018,3 +2068,18 @@ func contains(name string, names []string) bool {
 	}
 	return false
 }
+
+// validate returns nil if ImageLocationOrBuild is configured correctly.
+func (i ImageLocationOrBuild) validate() error {
+	if err := i.Build.validate(); err != nil {
+		return fmt.Errorf(`validate "build": %w`, err)
+	}
+	if !i.Build.isEmpty() && i.Location != nil {
+		return &errFieldMutualExclusive{
+			firstField:  "build",
+			secondField: "location",
+			mustExist:   true,
+		}
+	}
+	return nil
+}
