@@ -12,6 +12,7 @@ import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
+	"github.com/aws/copilot-cli/internal/pkg/manifest/manifestinfo"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 
 	"github.com/google/shlex"
@@ -62,11 +63,6 @@ var (
 	errUnmarshalCommand    = errors.New(`unable to unmarshal "command" into string or slice of strings`)
 )
 
-// WorkloadTypes returns the list of all manifest types.
-func WorkloadTypes() []string {
-	return append(ServiceTypes(), JobTypes()...)
-}
-
 // DynamicWorkload represents a dynamically populated workload.
 type DynamicWorkload interface {
 	ApplyEnv(envName string) (DynamicWorkload, error)
@@ -85,7 +81,7 @@ type workloadManifest interface {
 
 // UnmarshalWorkload deserializes the YAML input stream into a workload manifest object.
 // If an error occurs during deserialization, then returns the error.
-// If the workload type in the manifest is invalid, then returns an ErrInvalidManifestType.
+// If the workload type in the manifest is invalid, then returns an ErrInvalidmanifestinfo.
 func UnmarshalWorkload(in []byte) (DynamicWorkload, error) {
 	am := Workload{}
 	if err := yaml.Unmarshal(in, &am); err != nil {
@@ -94,15 +90,15 @@ func UnmarshalWorkload(in []byte) (DynamicWorkload, error) {
 	typeVal := aws.StringValue(am.Type)
 	var m workloadManifest
 	switch typeVal {
-	case LoadBalancedWebServiceType:
+	case manifestinfo.LoadBalancedWebServiceType:
 		m = newDefaultLoadBalancedWebService()
-	case RequestDrivenWebServiceType:
+	case manifestinfo.RequestDrivenWebServiceType:
 		m = newDefaultRequestDrivenWebService()
-	case BackendServiceType:
+	case manifestinfo.BackendServiceType:
 		m = newDefaultBackendService()
-	case WorkerServiceType:
+	case manifestinfo.WorkerServiceType:
 		m = newDefaultWorkerService()
-	case ScheduledJobType:
+	case manifestinfo.ScheduledJobType:
 		m = newDefaultScheduledJob()
 	default:
 		return nil, &ErrInvalidWorkloadType{Type: typeVal}
@@ -129,11 +125,16 @@ type Workload struct {
 
 // Image represents the workload's container image.
 type Image struct {
-	Build        BuildArgsOrString `yaml:"build"`           // Build an image from a Dockerfile.
-	Location     *string           `yaml:"location"`        // Use an existing image instead.
-	Credentials  *string           `yaml:"credentials"`     // ARN of the secret containing the private repository credentials.
-	DockerLabels map[string]string `yaml:"labels,flow"`     // Apply Docker labels to the container at runtime.
-	DependsOn    DependsOn         `yaml:"depends_on,flow"` // Add any sidecar dependencies.
+	ImageLocationOrBuild `yaml:",inline"`
+	Credentials          *string           `yaml:"credentials"`     // ARN of the secret containing the private repository credentials.
+	DockerLabels         map[string]string `yaml:"labels,flow"`     // Apply Docker labels to the container at runtime.
+	DependsOn            DependsOn         `yaml:"depends_on,flow"` // Add any sidecar dependencies.
+}
+
+// ImageLocationOrBuild represents the docker build arguments and location of the existing image.
+type ImageLocationOrBuild struct {
+	Build    BuildArgsOrString `yaml:"build"`    // Build an image from a Dockerfile.
+	Location *string           `yaml:"location"` // Use an existing image instead.
 }
 
 // DependsOn represents container dependency for a container.
@@ -168,7 +169,7 @@ func (i Image) GetLocation() string {
 // 2. Specific dockerfile, context = dockerfile dir
 // 3. "Dockerfile" located in context dir
 // 4. "Dockerfile" located in ws root.
-func (i *Image) BuildConfig(rootDirectory string) *DockerBuildArgs {
+func (i *ImageLocationOrBuild) BuildConfig(rootDirectory string) *DockerBuildArgs {
 	df := i.dockerfile()
 	ctx := i.context()
 	dockerfile := aws.String(filepath.Join(rootDirectory, defaultDockerfileName))
@@ -197,7 +198,7 @@ func (i *Image) BuildConfig(rootDirectory string) *DockerBuildArgs {
 
 // dockerfile returns the path to the workload's Dockerfile. If no dockerfile is specified,
 // returns "".
-func (i *Image) dockerfile() string {
+func (i *ImageLocationOrBuild) dockerfile() string {
 	// Prefer to use the "Dockerfile" string in BuildArgs. Otherwise,
 	// "BuildString". If no dockerfile specified, return "".
 	if i.Build.BuildArgs.Dockerfile != nil {
@@ -213,24 +214,24 @@ func (i *Image) dockerfile() string {
 }
 
 // context returns the build context directory if it exists, otherwise an empty string.
-func (i *Image) context() string {
+func (i *ImageLocationOrBuild) context() string {
 	return aws.StringValue(i.Build.BuildArgs.Context)
 }
 
 // args returns the args section, if it exists, to override args in the dockerfile.
 // Otherwise it returns an empty map.
-func (i *Image) args() map[string]string {
+func (i *ImageLocationOrBuild) args() map[string]string {
 	return i.Build.BuildArgs.Args
 }
 
 // target returns the build target stage if it exists, otherwise nil.
-func (i *Image) target() *string {
+func (i *ImageLocationOrBuild) target() *string {
 	return i.Build.BuildArgs.Target
 }
 
 // cacheFrom returns the cache from build section, if it exists.
 // Otherwise it returns nil.
-func (i *Image) cacheFrom() []string {
+func (i *ImageLocationOrBuild) cacheFrom() []string {
 	return i.Build.BuildArgs.CacheFrom
 }
 
@@ -791,7 +792,7 @@ func RedirectPlatform(os, arch, wlType string) (platform string, err error) {
 		return "", nil
 	}
 	// Return an error if a platform cannot be redirected.
-	if wlType == RequestDrivenWebServiceType && os == OSWindows {
+	if wlType == manifestinfo.RequestDrivenWebServiceType && os == OSWindows {
 		return "", ErrAppRunnerInvalidPlatformWindows
 	}
 	// All architectures default to 'x86_64' (though 'arm64' is now also supported); leave OS as is.
