@@ -4,6 +4,6 @@ import { TransformedStack } from '../stack';
 
 const app = new cdk.App();
 new TransformedStack(app, 'Stack', {
-    appName: process.env.COPILOT_APPLICATION_NAME,
-    envName: process.env.COPILOT_ENVIRONMENT_NAME,
+    appName: process.env.COPILOT_APPLICATION_NAME || "",
+    envName: process.env.COPILOT_ENVIRONMENT_NAME || "",
 });
\ No newline at end of file
