@@ -131,8 +131,6 @@ type SidecarOpts struct {
 	Name         string
 	Image        *string
 	Essential    *bool
-	Port         *string
-	Protocol     *string
 	CredsParam   *string
 	Variables    map[string]Variable
 	Secrets      map[string]Secret
@@ -142,6 +140,14 @@ type SidecarOpts struct {
 	EntryPoint   []string
 	Command      []string
 	HealthCheck  *ContainerHealthCheck
+	PortMappings []*PortMapping
+}
+
+// PortMapping holds container port mapping configuration.
+type PortMapping struct {
+	Protocol      string
+	ContainerPort uint16
+	ContainerName string
 }
 
 // SidecarStorageOpts holds data structures for rendering Mount Points inside of a sidecar.
@@ -232,6 +238,11 @@ func (tg HTTPTargetContainer) IsHTTPS() bool {
 	return tg.Port == "443"
 }
 
+// StrconvUint16 returns string converted from uint16.
+func StrconvUint16(val uint16) string {
+	return strconv.FormatUint(uint64(val), 10)
+}
+
 // HTTPHealthCheckOpts holds configuration that's needed for HTTP Health Check.
 type HTTPHealthCheckOpts struct {
 	// Fields with defaults always set.
@@ -271,6 +282,22 @@ func ImportedVariable(name string) Variable {
 	return importedEnvVar(name)
 }
 
+// Aliases return all the unique aliases specified across all the routing rules in NLB.
+// Currently, we only have primary routing rule, but we will be getting additional routing rule soon.
+func (cfg *NetworkLoadBalancer) Aliases() []string {
+	var uniqueAliases []string
+	seen := make(map[string]bool)
+	for _, listener := range cfg.Listener {
+		for _, entry := range listener.Aliases {
+			if _, value := seen[entry]; !value {
+				seen[entry] = true
+				uniqueAliases = append(uniqueAliases, entry)
+			}
+		}
+	}
+	return uniqueAliases
+}
+
 // PlainVariable returns a Variable that is a plain string value.
 func PlainVariable(value string) Variable {
 	return plainEnvVar(value)
@@ -423,9 +450,10 @@ type NLBHealthCheck struct {
 
 // NetworkLoadBalancer holds configuration that's needed for a Network Load Balancer.
 type NetworkLoadBalancer struct {
-	PublicSubnetCIDRs []string
-	Listener          NetworkLoadBalancerListener
-	MainContainerPort string
+	PublicSubnetCIDRs   []string
+	Listener            []NetworkLoadBalancerListener
+	MainContainerPort   string
+	CertificateRequired bool
 }
 
 // ServiceConnect holds configuration for ECS Service Connect.
@@ -509,6 +537,7 @@ type RollingUpdateRollbackConfig struct {
 	// Custom alarms to create.
 	CPUUtilization    *float64
 	MemoryUtilization *float64
+	MessagesDelayed   *int
 }
 
 // HasRollbackAlarms returns true if the client is using ABR.
@@ -518,7 +547,7 @@ func (cfg RollingUpdateRollbackConfig) HasRollbackAlarms() bool {
 
 // HasCustomAlarms returns true if the client is using Copilot-generated alarms for alarm-based rollbacks.
 func (cfg RollingUpdateRollbackConfig) HasCustomAlarms() bool {
-	return cfg.CPUUtilization != nil || cfg.MemoryUtilization != nil
+	return cfg.CPUUtilization != nil || cfg.MemoryUtilization != nil || cfg.MessagesDelayed != nil
 }
 
 // TruncateAlarmName ensures that alarm names don't exceed the 255 character limit.
@@ -699,9 +728,14 @@ type WorkloadOpts struct {
 	SerializedManifest string // Raw manifest file used to deploy the workload.
 	EnvVersion         string
 
+	// Configuration for the main container.
+	PortMappings []*PortMapping
+	Variables    map[string]Variable
+	Secrets      map[string]Secret
+	EntryPoint   []string
+	Command      []string
+
 	// Additional options that are common between **all** workload templates.
-	Variables                map[string]Variable
-	Secrets                  map[string]Secret
 	Aliases                  []string
 	HTTPSListener            bool
 	Tags                     map[string]string        // Used by App Runner workloads to tag App Runner service resources
@@ -716,8 +750,6 @@ type WorkloadOpts struct {
 	Network                  NetworkOpts
 	ExecuteCommand           *ExecuteCommandOpts
 	Platform                 RuntimePlatformOpts
-	EntryPoint               []string
-	Command                  []string
 	DomainAlias              string
 	DockerLabels             map[string]string
 	DependsOn                map[string]string
@@ -861,6 +893,7 @@ func withSvcParsingFuncs() ParseOption {
 			"pluralWord":           english.PluralWord,
 			"contains":             contains,
 			"requiresVPCConnector": requiresVPCConnector,
+			"strconvUint16":        StrconvUint16,
 		})
 	}
 }
