@@ -10,7 +10,7 @@ import (
 	"time"
 
 	"github.com/aws/copilot-cli/regression/client"
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 )
 
